<?php
defined('BASEPATH') OR exit('No direct script access allowed');

class Arquivos_model extends CI_Model {

  public function __construct() {
    parent::__construct();
    $this->load->database();
  }

  /**
   * Cadastrar um arquivo
   * @param $form -> Array com os dados do POST
   *
   * @return 'success' -> Fase Escolar cadastrada com sucesso
   * @return 'warning' -> Caso Fase Escolar já exista
   * @return 'danger' -> Algum erro de processamento
   */
  public function cadastrar( $form )
  {
    if( !empty($form['relation']) && !empty($form['arquivo']) )
    {
      $this->db->trans_start();

      // Salvar o arquivo
      $data = array(
        'arq_titulo' => trim($form['titulo']),
        'arq_titulo' => trim($form['titulo']),
        'arq_descricao' => trim($form['descricao']),
        'arq_url' => $form['arquivo']['file_name']
      );
      $sql = $this->db->insert_string('arquivo', $data );
      $result = $this->db->query( $sql );

      if( !$result )
      {
        return 'danger';
      }

      $id_arquivo = $this->db->insert_id();

      // Salvando a relacao com as turmas/materias
      $inserts = array();
      foreach ($form['relation'] AS $item)
      {
        $item = json_decode($item);
        $inserts[] = array(
          'arq_id' => $id_arquivo,
          'tur_id' => $item->tur_id,
          'mat_id' => $item->mat_id
        );
      }

      $this->db->insert_batch('arquivo_turma', $inserts );
      if( $this->db->affected_rows() )
      {
        $this->db->trans_complete();
        return 'success';
      }

    }

    return 'danger';
  }

  /**
   * 
   */
  public function excluir( $id )
  {
    $this->db->trans_start();

    // Removendo da relacao arquivo_turma
    $this->db->where('arq_id', $id);
    $this->db->delete('arquivo_turma');
    if( !$this->db->affected_rows() )
      return 'danger';

    // Removendo o arquivo em si
    $this->db->where('arq_id', $id);
    $this->db->delete('arquivo');

    if( $this->db->affected_rows() )
    {
      $this->db->trans_complete();
      return 'success';
    }

    return 'danger';
  }

  /**
   * 
   * @param $id -> ID do aluno
   */
  public function get_aluno_arquivos( $id )
  {
    $this->db->select('*');
    $this->db->from('arquivo');
    $this->db->join('arquivo_turma', 'arquivo_turma.arq_id = arquivo.arq_id'); // Relacionando as turmas
    $this->db->join('turma', 'turma.tur_id = arquivo_turma.tur_id'); // Relacionando o arquivo com a turma
    $this->db->join('fase_escolar', 'fase_escolar.fas_id = turma.fas_id'); // Relacionando a turma com a fase escolar
    $this->db->join('usuario_turma', 'usuario_turma.tur_id = turma.tur_id'); // Relacionando as turmas
    $this->db->join('materia', 'materia.mat_id = arquivo_turma.mat_id'); // Relacionando a turma com a fase escolar
    // $this->db->group_by('arquivo.arq_id');
    $this->db->order_by('arquivo.arq_id', 'desc');
    $this->db->order_by('materia.mat_nome', 'asc');
    $this->db->where('usuario_turma.usu_id', $id); // Usuario especifico
    
    $query = $this->db->get();

    if( !$this->db->affected_rows() )
      return false;

    $arquivos = array();
    foreach ($query->result() AS $arquivo)
    {
      $arquivos[$arquivo->mat_nome][] = $arquivo;
    }

    return $arquivos;
  }

  /**
   * 
   * @param $id -> ID do professor
   */
  public function get_professor_arquivos( $id )
  {
    $this->db->select('*');
    $this->db->from('arquivo');
    $this->db->join('arquivo_turma', 'arquivo_turma.arq_id = arquivo.arq_id'); // Relacionando as turmas
    $this->db->join('turma', 'turma.tur_id = arquivo_turma.tur_id'); // Relacionando o arquivo com a turma
    $this->db->join('fase_escolar', 'fase_escolar.fas_id = turma.fas_id'); // Relacionando a turma com a fase escolar
    $this->db->join('professor_turma', 'professor_turma.tur_id = turma.tur_id'); // Relacionando as turmas
    // $this->db->group_by('arquivo.arq_id');
    $this->db->order_by('arquivo.arq_id', 'desc');
    $this->db->order_by('fas_nome', 'asc');
    $this->db->order_by('tur_nome', 'asc');
    $this->db->where('professor_turma.usu_id', $id); // Usuario especifico
    $query = $this->db->get();

    if( !$this->db->affected_rows() )
      return false;
    
    // Reduzindo os arquivos sem GROUPBY para saber as Turmas que ele pertence
    $arquivos = array();
    foreach ($query->result() AS $item)
    {
      $arq =& $arquivos[ $item->arq_id ];

      // Para nao gerar reescrita de array
      if( empty($arq) || !isset($arq)  )
        $arq = (array) $item;

      $turma = $item->fas_nome . ' ' .$item->tur_nome;
      if( empty($arq['turmas']) || !in_array($turma, $arq['turmas']) )
        $arq['turmas'][] = $turma;
    }
      
    return $arquivos;
  }

}
