<?php
defined('BASEPATH') OR exit('No direct script access allowed');

class Avisos_model extends CI_Model {

  public function __construct() {
    parent::__construct();
    $this->load->database();
  }

  /**
   * Cadastrar uma nova matéria
   * @param $form -> Array com os dados do POST
   *
   * @return 'success' -> Matéria cadastrada com sucesso
   * @return 'warning' -> Caso matéria já exista
   * @return 'danger' -> Algum erro de processamento
   */
  public function cadastrar( $form )
  {
    if( !empty($form['data']) )
    {
      $data = array('avi_dataVisibilidade'=> $form['data'], 'avi_titulo'=> $form['titulo'], 'avi_aviso'=>$form['aviso']);

      // Efetua o INSERT
      $sql = $this->db->insert_string('aviso', $data );
      $result = $this->db->query( $sql );

      if( $result )
      {
        //Pegando o id do aviso cadastrado
        $this->db->select_max('avi_id');
        $query = $this->db->get('aviso');

        if(isset($form['turmas'])) 
        { 
          foreach($form['turmas'] as $turma) 
          {
            foreach ($query->result() as $row)
            {
              $data = array('avi_id'=> $row->avi_id, 'tur_id'=> $turma);
            }
            //Efetua o INSERT na tabela intermediaria
            $sql = $this->db->insert_string('aviso_turma', $data );
            $result = $this->db->query( $sql );
          } 
          return 'success';
        }
      }
    }
    return "danger";
  }

  /**
   * Lista todas os avisos
   *
   * @return Array de objetos com as matérias
   */
  public function get_avisos()
  {
    $avisos = $this->db->get('aviso');

    return $avisos->result();
  }

  /**
   * Lista todas os avisos_turma
   *
   * @return Array de objetos com as matérias
   */
  public function get_aviso_turma()
  {
    $at = $this->db->get('aviso_turma');

    return $at->result();
  }

  /**
   * Lista todas os avisos da turma
   *
   * @return Array de objetos com as matérias
   */
  public function get_avisosdaturma($id)
  {
    $hoje = date('Y-m-d');
   
   // Pegando os avisos da turma
    $this->db->select('*');
    $this->db->from('aviso_turma');
    $this->db->join('aviso', 'aviso_turma.avi_id = aviso.avi_id');
    $this->db->where('tur_id', $id);
    $this->db->where('avi_dataVisibilidade >=', $hoje); 
    $query = $this->db->get();

    return $query->result();
  }

  /**
   * Excluir
   */
  public function excluir( $id )
  {
    $this->db->where('avi_id', $id);
    $this->db->delete('aviso_turma');
    if( $this->db->affected_rows() )
    {
      $this->db->where('avi_id', $id);
      $this->db->delete('aviso');

      if( $this->db->affected_rows() )
        return 'success';
    }
    return 'danger';
  }
}
