<?php
defined('BASEPATH') OR exit('No direct script access allowed');

class FasesEscolares_model extends CI_Model {

  public function __construct() {
    parent::__construct();
    $this->load->database();
  }

  /**
   * Cadastrar uma nova fase escolar
   * @param $form -> Array com os dados do POST
   *
   * @return 'success' -> Fase Escolar cadastrada com sucesso
   * @return 'warning' -> Caso Fase Escolar já exista
   * @return 'danger' -> Algum erro de processamento
   */
  public function cadastrar( $form )
  {
    if( !empty($form['nome']) )
    {
      $data = array('fas_nome'=> $form['nome']);

      // Verifica existencia
      $result = $this->db->get_where('fase_escolar', $data);
      $result = $result->result();

      if( $result )
      {
        return 'warning';
      }

      // Efetua o INSERT
      $sql = $this->db->insert_string('fase_escolar', $data );
      $result = $this->db->query( $sql );

      if( $result )
      {
        //Pegando o id da fase escolar cadastrada
        $this->db->select_max('fas_id');
        $query = $this->db->get('fase_escolar');

        if(isset($form['materias'])) 
        { 
          foreach($form['materias'] as $materia) 
          {
            foreach ($query->result() as $row)
            {
              $data = array('fas_id'=> $row->fas_id, 'mat_id'=> $materia);
            }
            //Efetua o INSERT na tabela intermediaria
            $sql = $this->db->insert_string('fase_escolar_materia', $data );
            $result = $this->db->query( $sql );
          } 
          return 'success';
        }
      } 
    }
    return "danger";
  }


  /**
   * Editar uma fase escolar
   * @param $id -> ID da fase escolar a ser alterada
   * @param $form -> Array com os dados do POST
   *
   * @return 'success' -> fase escolar alterada com sucesso
   * @return 'warning' -> Caso fase escolar já exista
   * @return 'danger' -> Algum erro de processamento
   */
  public function editar( $id, $form )
  {
    if( !empty($form['nome']) )
    {
      $data = array('fas_nome'=> $form['nome']);
      $result = $this->db->update('fase_escolar', $data, array('fas_id'=>$id));
      if( $result )
      {
        $this->db->where('fas_id', $id);
        $this->db->delete('fase_escolar_materia');

        if(isset($form['materias']))
        { 
          foreach($form['materias'] as $materia) 
          {
            $data = array('fas_id'=> $id, 'mat_id'=> $materia);  
            //Efetua o INSERT na tabela intermediaria
            $sql = $this->db->insert_string('fase_escolar_materia', $data );
            $result = $this->db->query( $sql );
          } 
        }
        return 'success';
      } 
    }
    
    return "danger";
  }


  /**
   * Lista todas as matérias cadastradas
   *
   * @return Array de objetos com as matérias
   */
  public function get_materias()
  {
    $materias = $this->db->get('materia');

    return $materias->result();
  }

   /**
   * Lista todas as Fases Escolares cadastradas
   *
   * @return Array de objetos com as matérias
   */
  public function get_fasesescolares()
  {
    $fasesescolares = $this->db->get('fase_escolar');

    return $fasesescolares->result();
  }


  /**
   * Lista apenas uma fase escolar
   * @param $id -> ID da fase escolar a ser consultada
   *
   * @return (1) Objeto da faseescolar
   * @return (2) false
   */
  public function get_faseescolar( $id )
  {
    $faseescolar = $this->db->get_where('fase_escolar', array('fas_id'=>$id));
    $faseescolar = $faseescolar->result();

    if( !empty($faseescolar) )
      return current( $faseescolar );

    return false;
  }


  /**
   * Lista todas as associações da fase escolar com as matérias
   *
   * @return Array de objetos com as associações
   */
  public function get_fasesescolares_materias( $id )
  {
    $faseescolar = $this->db->get_where('fase_escolar_materia', array('fas_id'=>$id));
    $faseescolar = $faseescolar->result();

    if( !empty($faseescolar) )
      return $faseescolar;

    return false;
  }

  /**
   * Lista todas as associações da fase escolar com as matérias
   *
   * @return Array de objetos com as associações
   */
  public function get_todas_fasesescolares_materias()
  {
    $sql  = "SELECT * FROM fase_escolar_materia fm ";
    $sql .= "JOIN fase_escolar f ON fm.fas_id = f.fas_id ";
    $sql .= "JOIN materia m ON fm.mat_id = m.mat_id ";

    $result = $this->db->query($sql);
    return $result->result();
  }

}
