<?php
defined('BASEPATH') OR exit('No direct script access allowed');

class Lancamentos_model extends CI_Model {

  public function __construct() {
    parent::__construct();
    $this->load->database();
  }

  /**
   * Cadastrar um novo lançamento
   * @param $form -> Array com os dados do POST
   *
   * @return 'success' -> Matéria cadastrada com sucesso
   * @return 'warning' -> Caso matéria já exista
   * @return 'danger' -> Algum erro de processamento
   */
  public function cadastrar( $form, $materias = false, $ava_id = false, $alunos = false )
  {
    if( !empty($form['nome']) )
    {
      $this->load->model('Configuracao_model');

      //Pegando o bimestre
      $bimprova = $this->Configuracao_model->get_bimestredata($form['datacadastro']);

      if($bimprova == "N")
      {
        return 'warning';
      }

      //listando turmas selecionadas
      $turmas = $form['turmas'];
      foreach($form['turmas'] as $key => $turma_id) 
      {
        //listando as associações com as matérias da turma
        $this->load->model('Turmas_model');
        if( $materias === false )
          $materias = $this->Turmas_model->get_fase_escolar_materia( $turma_id );

        foreach ($materias as $materia)
        {
          //fazendo inset do lançamento
          $data = array('lan_nome'=> $form['nome'], 'lan_datalimite'=> $form['datacadastro'], 'lan_bimestre'=> $bimprova, 'mat_id'=> $materia->mat_id, 'tur_id'=> $turma_id);

          if( $ava_id )
            $data['ava_id'] = $ava_id;

          if( isset($form['discursiva']) )
            $data['lan_discursiva'] = 1;

          $sql = $this->db->insert_string('lancamento', $data );
          $result = $this->db->query( $sql );
          
          //Pegando o id da turma cadastrada
          if( $this->db->affected_rows() )
          {
            $lan_id = $this->db->insert_id();
            if( $alunos === false )
              $alunos = $this->Turmas_model->get_turma_alunos( $turma_id );
            foreach ($alunos as $aluno) 
            {
              //fazendo inset da nota do aluno 
              $data2 = array('usu_id'=> $aluno->usu_id, 'lan_id'=> $lan_id, 'mat_id'=> $materia->mat_id, 'not_bimestre'=> $bimprova, 'not_nota'=> 0);
              $sql2 = $this->db->insert_string('nota', $data2 );
              $result2 = $this->db->query( $sql2 );
              
              if(!$result2)
              {
                return 'danger';
              }
            }
          }
        }
        $materias = false;
        $alunos = false;

      }
      return 'success';
    }
    return "danger";
  }


  /**
   * Editar uma matéria
   * @param $id -> ID da matéria a ser alterada
   * @param $form -> Array com os dados do POST
   *
   * @return 'success' -> Matéria alterada com sucesso
   * @return 'danger' -> Algum erro de processamento
   */
  public function notas( $form, $id )
  {
    // pegando as notas do aluno
    $notas = $this->Lancamentos_model->get_notas($id);
    foreach ($notas as $nota) 
    {
      $data = array('not_nota'=> $form[$nota->not_id]);
      $result = $this->db->update('nota', $data, array('not_id'=> $nota->not_id));
      if(!$result)
      {
        return 'danger';
      }
    }
    return 'success';
  }


  /**
   * Lista todas os lançamentos agrupados por turma
   *
   * @return Array de objetos
   */
  public function get_lancamentos( $id = null, $bimestre = null )
  {
    // Trigger para correção de padrao, (NAO SEI ONDE OS LUGARES ONDE ESTA SENDO CHAMADO GET_LANCAMENTO)
    // POR ISSO O DIRECIONAMENTE PARA O METHOD QUE DEVERIA SER O "ORIGINAL"
    if( $id !== null && $bimestre !==null )
      return $this->get_lancamentos_turma($id, $bimestre);

    $this->load->model('Configuracao_model');
    $bimestre = ($bimestre !== null) ? $bimestre : $this->Configuracao_model->get_bimestre();

    // Pegando todas os lancamentos realmente
    $rs = $this->db->select('*')
              ->from('lancamento')
              ->join('materia', 'materia.mat_id = lancamento.mat_id')
              ->join('turma', 'turma.tur_id = lancamento.tur_id')
              ->join('fase_escolar', 'fase_escolar.fas_id = turma.fas_id')
              ->where('lan_bimestre', $bimestre)
              ->order_by('turma.tur_nome', 'ASC')
              ->order_by('fase_escolar.fas_nome', 'ASC')
              ->group_by('lancamento.tur_id')
              ->get();

    if( $this->db->affected_rows() )
      return $rs->result();

    // $lans = array();
    // foreach ($rs->result() AS $lan) {
    //   $lans[ $lan->tur_id ][] = $lan;
    // }

    return;
  }


  public function get_lancamentos_turma( $id, $bimestre )
  {
    $this->db->where('lancamento.tur_id', $id);
    $this->db->where('lan_bimestre', $bimestre);
    $this->db->join('materia', 'materia.mat_id = lancamento.mat_id');
    $this->db->join('turma', 'turma.tur_id = lancamento.tur_id');
    $this->db->order_by('materia.mat_nome', 'ASC');
    $lancamentos = $this->db->get('lancamento');

    return $lancamentos->result();
  }


  /**
   * Responsavel por exibir os laçamentos que o professor é "responsavel" 
   * @param $usu_id -> ID do professor
   * @param $tur_id -> ID da turma
   * @param $bimestre -> 
   *
   * @return Array de objetos
   */
  public function get_lancamentos_professor( $usu_id, $tur_id = false, $bimestre = false )
  {
    $this->db->select('*');
    $this->db->from('lancamento');
    $this->db->join('turma', 'turma.tur_id = lancamento.tur_id');
    $this->db->join('fase_escolar', 'fase_escolar.fas_id = turma.fas_id');
    $this->db->join('professor_turma', 'professor_turma.tur_id = lancamento.tur_id AND lancamento.mat_id=professor_turma.mat_id');
    $this->db->join('materia', 'materia.mat_id = professor_turma.mat_id');
    $this->db->where('professor_turma.usu_id', $usu_id);

    if( $tur_id !== false )
      $this->db->where('lancamento.tur_id', $tur_id);

    if( $bimestre !== false )
      $this->db->where('lancamento.lan_bimestre', $bimestre);

    $this->db->where('lancamento.ava_id IS NULL');

    $this->db->or_where('lancamento.ava_id IS NOT NULL AND lancamento.lan_discursiva IS NOT NULL');

    $this->db->order_by('lancamento.lan_datalimite', 'ASC'); // Só para prevenção
    $rs = $this->db->get();

    if( $this->db->affected_rows() )
      return $rs->result();

    return;
  }


  /**
   * Lista todas as notas
   *
   * @return Array de objetos com as notas
   */
  public function get_notas( $id )
  {
    $this->db->where('nota.lan_id', $id);
    $this->db->join('materia', 'materia.mat_id = nota.mat_id');
    $this->db->join('usuario', 'usuario.usu_id = nota.usu_id');
    $this->db->order_by('usuario.usu_nome', 'ASC');
    $notas = $this->db->get('nota');

    return $notas->result();
  }


  /**
   * Lista todas as notas
   * @param $tur_id -> ID da turma
   * @param $bimestre -> Retornar referente apenas aquele bimestre
   *
   * @return Array de objetos das notas
   */
  public function get_notas_turma( $tur_id, $bimestre='', $mat_id='' )
  {
    $this->db->select('*');
    $this->db->from('nota');
    $this->db->join('lancamento', 'lancamento.lan_id = nota.lan_id');
    $this->db->join('materia', 'materia.mat_id = lancamento.mat_id');
    $this->db->join('usuario', 'usuario.usu_id = nota.usu_id');

    if( !empty($bimestre) )
      $this->db->where('nota.not_bimestre', $bimestre);

    if( !empty($mat_id) )
      $this->db->where('nota.mat_id', $mat_id);
      
    $this->db->where('lancamento.tur_id', $tur_id);
    $rs = $this->db->get();

    return $rs->result();
  }

  /**
   * 
   * 
   */
  public function get_turma_notas($tur_id, $bimestre='')
  {
    $this->load->model('Turmas_model');
    $this->load->model('ListaExercicios_model');
    $notas = $this->get_notas_turma($tur_id, $bimestre);

    if( !empty($notas) )
    {
      // Faz a soma das notas de cada aluno, e coloca em uma arvore Aluno -> Bimestre -> Materia
      $alunos = array();
      foreach ($notas AS $aluno) {
        if( !isset($alunos[ $aluno->usu_id ][ $aluno->not_bimestre ][ $aluno->mat_id ]) )
          $alunos[ $aluno->usu_id ][ $aluno->not_bimestre ][ $aluno->mat_id ] = array_merge( (array) $aluno ,array('nota_final' => 0 ));

        $nota =& $alunos[ $aluno->usu_id ][ $aluno->not_bimestre ][ $aluno->mat_id ]['nota_final'];
        $nota += $aluno->not_nota;
      }

      // Faz o arredondamento e soma das notas (por bimestre)
      unset($notas);
      $notas = array();
      foreach ($alunos AS $bimestre) {
        foreach ($bimestre AS $materias) {
          $aux = current($materias);
          $lista = $this->ListaExercicios_model->get_relacao_entregue( $aux['usu_id'] , $aux['not_bimestre']  );

          foreach ($materias AS $mat) {
            $nota_aux = $mat['nota_final'];

            // Adicionando a nota de listas de exercicios
            if( isset($lista[$mat['mat_id']]) )
              $nota_aux += $lista[$mat['mat_id']]['lis_nota_final'];

            if( !isset($notas[ $mat['usu_id'] ][ $mat['mat_id'] ]) )
            {
              $notas[ $mat['usu_id'] ][ $mat['mat_id'] ] = $mat;
              $notas[ $mat['usu_id'] ][ $mat['mat_id'] ]['nota_final'] = $this->arredondamento_nota($nota_aux);
            }
            else
            {
              $notas[ $mat['usu_id'] ][ $mat['mat_id'] ]['nota_final'] += $this->arredondamento_nota($nota_aux);
            }
            
          }
        }
      }

      return $notas;
    }

    return;
  }


  /**
   * Faz o arredondamento da nota
   * @param $nota -> Nota a ser arredondada (geralmente bimestral)
   *
   * @return $nota arredondada
   */
  public function arredondamento_nota($nota)
  {
    if($nota >= 0.7 && $nota <= 0.9) $nota = 1;
    elseif($nota >= 1.7 && $nota <= 1.9) $nota = 2;
    elseif($nota >= 2.7 && $nota <= 2.9) $nota = 3;
    elseif($nota >= 3.7 && $nota <= 3.9) $nota = 4;
    elseif($nota >= 4.7 && $nota <= 4.9) $nota = 5;
    elseif($nota >= 5.7 && $nota <= 5.9) $nota = 6;
    elseif($nota >= 6.7 && $nota <= 6.9) $nota = 7;
    elseif($nota >= 7.7 && $nota <= 7.9) $nota = 8;
    elseif($nota >= 8.7 && $nota <= 8.9) $nota = 9;
    elseif($nota >= 9.7 && $nota <= 9.9) $nota = 10;

    return $nota;
  }


  /**
   * Lista apenas uma matéria
   * @param $id -> ID da matéria a consultada
   *
   * @return (1) Objeto da materia
   * @return (2) false
   */
  public function get_lancamento( $id )
  {
    $this->db->where('lancamento.lan_id', $id);
    $this->db->join('materia', 'materia.mat_id = lancamento.mat_id');
    $this->db->join('turma', 'turma.tur_id = lancamento.tur_id');
    $this->db->join('fase_escolar', 'fase_escolar.fas_id = turma.fas_id');
    $this->db->order_by('materia.mat_nome', 'ASC');
    $lancamento = $this->db->get('lancamento');
    $lancamento = $lancamento->result();

    if( !empty($lancamento) )
      return current( $lancamento );
    return false;
  }

}
