<?php
defined('BASEPATH') OR exit('No direct script access allowed');

class ListaExercicios_model extends CI_Model {

  public function __construct() {
    parent::__construct();
    $this->load->database();
  }

  /**
   * Cadastrar um arquivo
   * @param $form -> Array com os dados do POST
   *
   * @return 'success' -> Fase Escolar cadastrada com sucesso
   * @return 'warning' -> Caso Fase Escolar já exista
   * @return 'danger' -> Algum erro de processamento
   */
  public function cadastrar( $form, $tur_id )
  {
    if( !empty($form['numero']) && !empty($form['materia']) )
    {
      // Excedeu o limite de listas por bimestre
      if( $form['numero']>11 )
        return 'warning';

      $this->load->model('Configuracao_model');

      /*
       * Cadastra a lista */
      $data = array(
        'lis_numero'      => $form['numero'],
        'tur_id'          => $tur_id,
        'mat_id'          => $form['materia'],
        'lis_bimestre'    => $this->Configuracao_model->get_bimestre(),
      );
      $query = $this->db->insert_string('lista_exercicio', $data );
      $this->db->query( $query );

      if( !$this->db->affected_rows() )
        return 'danger';

      if( empty($form['alunos']) )
        return 'success';

      /*
       * Prepara para cadastrar os alunos que ja entregaram */
      $lis_id = $this->db->insert_id(); // ID da lista criada
      $data = array();
      foreach ($form['alunos'] AS $aluno)
        $data[] = array(
          'lis_id'        => $lis_id,
          'usu_id'        => $aluno,
        );

      $this->db->insert_batch('lista_exercicio_entregue', $data );
      if( $this->db->affected_rows() )
        return 'success';
    }

    return 'danger';
  }

  public function editar($form, $lis_id)
  {
    // Ela vai trazer todos os alunos no form($form['alunos'])
    // Por isso remove todas as listas referentes aquela lista, e insere novamente (atualizados)
    $this->db->where('lis_id', $lis_id);
    $this->db->delete('lista_exercicio_entregue');

    // Foi removido tudo da lista
    if( empty($form['alunos']) )
      return 'success';

    // Criando um escopo para a inserção
    $data = array();
    foreach( $form['alunos'] AS $id )
    {
      $data[] = array( 'usu_id' => $id, 'lis_id' => $lis_id );
    }

    // Insere novamente
    $this->db->insert_batch('lista_exercicio_entregue', $data );
    if( $this->db->affected_rows() )
    {
      $this->db->trans_complete();
      return 'success';
    }
    
    return 'danger';
  }


  /**
   * 
   */
  public function excluir( $lis_id )
  {
    $this->db->trans_start();

    // Removendo da relacao lista_exercicio_entregue
    $this->db->where('lis_id', $lis_id);
    $this->db->delete('lista_exercicio_entregue');
    if( !$this->db->affected_rows() )
      return 'danger';

    // Removendo a lista em si
    $this->db->where('lis_id', $lis_id);
    $this->db->delete('lista_exercicio');

    if( $this->db->affected_rows() )
    {
      $this->db->trans_complete();
      return 'success';
    }

    return 'danger';
  }


  /**
   * Responsavel por contabilizar o total de listas com o total de listas entregues pelo aluno
   * @param $usu_id -> ID do aluno
   * @param $bimestre
   * 
   * @return Array(mat_id)(total|entregue)
   */
  public function get_relacao_entregue($usu_id, $bimestre)
  {
    // Total de lista (de todas as materias)
     $listas_entregue = $this->db->select('*')
                                        ->from('lista_exercicio_entregue')
                                        ->join('lista_exercicio', 'lista_exercicio.lis_id = lista_exercicio_entregue.lis_id')
                                        ->where('lista_exercicio_entregue.usu_id', $usu_id)
                                        ->where('lista_exercicio.lis_bimestre', $bimestre)
                                        ->get();

    if( $listas_entregue->num_rows() > 0 )
    {
      $row = $listas_entregue->row();
      $tur_id = $row->tur_id;

      $listas = $this->db->select('*')
                          ->from('lista_exercicio')
                          ->where('lis_bimestre', $bimestre)
                          ->where('tur_id', $tur_id)
                          ->get();

      // Contabilizando o total de listas
      $materias = array();
      foreach ($listas->result() AS $mat) {
        if( !isset($materias[$mat->mat_id]) )
          $materias[$mat->mat_id] = array(
            'total' => 0,
            'lis_id' => $mat->lis_id,
            'entregue' => 0,
            'lis_nota_final' => 0);

        $materias[$mat->mat_id]['total']++;
      }

      // Contabilizando o total de listas entregues pelo usuario
      foreach ($listas_entregue->result() AS $ent) {
        $materias[$ent->mat_id]['entregue']++;
      }

      // Calculando a nota
      foreach ($materias AS $mat_id => $item) {
        // Porcentagem (p)
        // Total de Listas(tl)
        // Total de Entregas(te)

        $tl = $item['total'];
        $te = $item['entregue'];

        $p = ($te*100)/$tl;

        if($p == 0) $nota = 0;
        elseif($p < 50) $nota = 0.5;
        elseif($p >= 50) $nota = 1;

        $materias[$mat_id]['lis_nota_final'] = $nota;
      }

      return $materias;
    }

    return;
  }
  

  /**
   * 
   * @param $id -> ID do aluno
   */
  public function get_aluno_arquivos( $id )
  {
    $this->db->select('*');
    $this->db->from('arquivo');
    $this->db->join('arquivo_turma', 'arquivo_turma.arq_id = arquivo.arq_id'); // Relacionando as turmas
    $this->db->join('turma', 'turma.tur_id = arquivo_turma.tur_id'); // Relacionando o arquivo com a turma
    $this->db->join('fase_escolar', 'fase_escolar.fas_id = turma.fas_id'); // Relacionando a turma com a fase escolar
    $this->db->join('usuario_turma', 'usuario_turma.tur_id = turma.tur_id'); // Relacionando as turmas
    $this->db->join('materia', 'materia.mat_id = arquivo_turma.mat_id'); // Relacionando a turma com a fase escolar
    // $this->db->group_by('arquivo.arq_id');
    $this->db->order_by('arquivo.arq_id', 'desc');
    $this->db->order_by('materia.mat_nome', 'asc');
    $this->db->where('usuario_turma.usu_id', $id); // Usuario especifico
    
    $query = $this->db->get();

    if( !$this->db->affected_rows() )
      return false;

    $arquivos = array();
    foreach ($query->result() AS $arquivo)
    {
      $arquivos[$arquivo->mat_nome][] = $arquivo;
    }

    return $arquivos;
  }

  /**
   * 
   * @param $id -> ID do professor
   */
  public function get_professor_arquivos( $id )
  {
    $this->db->select('*');
    $this->db->from('arquivo');
    $this->db->join('arquivo_turma', 'arquivo_turma.arq_id = arquivo.arq_id'); // Relacionando as turmas
    $this->db->join('turma', 'turma.tur_id = arquivo_turma.tur_id'); // Relacionando o arquivo com a turma
    $this->db->join('fase_escolar', 'fase_escolar.fas_id = turma.fas_id'); // Relacionando a turma com a fase escolar
    $this->db->join('professor_turma', 'professor_turma.tur_id = turma.tur_id'); // Relacionando as turmas
    // $this->db->group_by('arquivo.arq_id');
    $this->db->order_by('arquivo.arq_id', 'desc');
    $this->db->order_by('fas_nome', 'asc');
    $this->db->order_by('tur_nome', 'asc');
    $this->db->where('professor_turma.usu_id', $id); // Usuario especifico
    $query = $this->db->get();

    if( !$this->db->affected_rows() )
      return false;
    
    // Reduzindo os arquivos sem GROUPBY para saber as Turmas que ele pertence
    $arquivos = array();
    foreach ($query->result() AS $item)
    {
      $arq =& $arquivos[ $item->arq_id ];

      // Para nao gerar reescrita de array
      if( empty($arq) || !isset($arq)  )
        $arq = (array) $item;

      $turma = $item->fas_nome . ' ' .$item->tur_nome;
      if( empty($arq['turmas']) || !in_array($turma, $arq['turmas']) )
        $arq['turmas'][] = $turma;
    }
      
    return $arquivos;
  }


  /**
   * 
   * @param $tur_id - > ID da turma
   * @param $usu_id - > ID do professor
   */
  public function get_listas( $tur_id, $usu_id )
  {
             $this->db->select('lista_exercicio.*, count(1) as total_entregue');
             // $this->db->select('*');
             $this->db->from('lista_exercicio');
             $this->db->join('lista_exercicio_entregue', 'lista_exercicio_entregue.lis_id = lista_exercicio.lis_id', 'left');

             $this->db->join('turma', 'turma.tur_id = lista_exercicio.tur_id');
             $this->db->join('professor_turma', 'professor_turma.tur_id = lista_exercicio.tur_id AND professor_turma.mat_id=lista_exercicio.mat_id');

             $this->db->where('lista_exercicio.tur_id', $tur_id);
             $this->db->where('professor_turma.usu_id', $usu_id);
             $this->db->where('professor_turma.tur_id', $tur_id);

             $this->db->order_by('lis_numero', 'desc');
             $this->db->group_by('lista_exercicio.lis_id');
    $query = $this->db->get();

    if( $this->db->affected_rows() )      
      return $query->result();
  }

  public function get_lista( $lis_id )
  {
    $rs = $this->db->select('lista_exercicio.*, lista_exercicio_entregue.usu_id')
                    ->from('lista_exercicio')
                    ->join('lista_exercicio_entregue', 'lista_exercicio_entregue.lis_id = lista_exercicio.lis_id', 'left')
                    ->where('lista_exercicio.lis_id', $lis_id)
                    ->get();
    
    if( $this->db->affected_rows() )
      return $rs->result();

    return;
  }
}
