<?php
defined('BASEPATH') OR exit('No direct script access allowed');

class Materias_model extends CI_Model {

  public function __construct() {
    parent::__construct();
    $this->load->database();
  }

  /**
   * Cadastrar uma nova matéria
   * @param $form -> Array com os dados do POST
   *
   * @return 'success' -> Matéria cadastrada com sucesso
   * @return 'warning' -> Caso matéria já exista
   * @return 'danger' -> Algum erro de processamento
   */
  public function cadastrar( $form )
  {
    if( !empty($form['nome']) )
    {
      $data = array('mat_nome'=> $form['nome']);

      // Verifica existencia
      $result = $this->db->get_where('materia', $data);
      $result = $result->result();

      if( $result )
      {
        return 'warning';
      }

      // Efetua o INSERT
      $sql = $this->db->insert_string('materia', $data );
      $result = $this->db->query( $sql );

      if( $result )
      {
        return 'success';
      } 
    }
    
    return "danger";
  }


  /**
   * Editar uma matéria
   * @param $id -> ID da matéria a ser alterada
   * @param $form -> Array com os dados do POST
   *
   * @return 'success' -> Matéria alterada com sucesso
   * @return 'warning' -> Caso matéria já exista
   * @return 'danger' -> Algum erro de processamento
   */
  public function editar( $id, $form )
  {
    if( !empty($form['nome']) )
    {
      $data = array('mat_nome'=> $form['nome']);

      // Verifica existencia
      $result = $this->db->get_where('materia', $data);
      $result = $result->result();

      if( $result )
      {
        return 'warning';
      }

      $result = $this->db->update('materia', $data, array('mat_id'=>$id));

      if( $result )
      {
        return 'success';
      } 
    }
    
    return "danger";
  }


  /**
   * Lista todas as matérias cadastradas
   *
   * @return Array de objetos com as matérias
   */
  public function get_materias()
  {
    $materias = $this->db->get('materia');

    return $materias->result();
  }


  /**
   * Lista a(s) materia(s) que o professor ministra
   * Com a opção de retornar apenas da turma especifica
   * @param $usu_id -> ID do professor
   *
   * @return (1) Objeto da materia
   * @return (2) false
   */
  public function get_materia_professor( $usu_id, $tur_id = false, $group_by = false )
  {
    $this->db->select('*');
    $this->db->from('turma');
    $this->db->join('professor_turma', 'professor_turma.tur_id = turma.tur_id'); // Relacionando as turmas
    $this->db->join('fase_escolar', 'fase_escolar.fas_id = turma.fas_id'); // Relacionando a turma com a fase escolar
    $this->db->join('materia', 'materia.mat_id = professor_turma.mat_id'); // Relacionando a turma/professor materias
    $this->db->where('professor_turma.usu_id', $usu_id); // Usuario especifico

    if( !empty($tur_id) )
      $this->db->where('turma.tur_id', $tur_id); // Turma especifica

    $this->db->order_by('fas_nome', 'asc');
    $this->db->order_by('tur_nome', 'asc');

    if( !empty($group_by) )
      $this->db->group_by('materia.mat_id');

    $query = $this->db->get();

    if( $this->db->affected_rows() )
      return $query->result();

    return;
  }


  /**
   * Lista apenas uma matéria
   * @param $id -> ID da matéria a consultada
   *
   * @return (1) Objeto da materia
   * @return (2) false
   */
  public function get_materia( $id )
  {
    $materia = $this->db->get_where('materia', array('mat_id'=>$id));
    $materia = $materia->result();

    if( !empty($materia) )
      return current( $materia );

    return false;
  }

}
