<?php
defined('BASEPATH') OR exit('No direct script access allowed');

class Relatorios_model extends CI_Model {

  public function __construct() {
    parent::__construct();
    $this->load->database();
    $this->load->library('fpdf_loader');
  }

  public function get_anual_v1($tur_id)
  {
    $this->load->model('Lancamentos_model');
    $this->load->model('Turmas_model');
    $turma = $this->Turmas_model->get_turma($tur_id);
    $notas = $this->Lancamentos_model->get_notas_turma($tur_id);
    
    // Faz a soma das notas de cada aluno, e coloca em uma arvore Aluno -> Materia
    $alunos = array();
    foreach ($notas AS $aluno) {
      if( !isset($alunos[ $aluno->usu_id ][ $aluno->mat_id ]) )
        $alunos[ $aluno->usu_id ][ $aluno->mat_id ] = array_merge( (array) $aluno ,array('nota_final' => 0 ));

      $nota =& $alunos[ $aluno->usu_id ][ $aluno->mat_id ]['nota_final'];
      $nota += $aluno->not_nota;
    }

    $title = "Relatório Anual ". $turma->fas_nome .' '. $turma->tur_nome;
    $this->fpdf->SetTitle($title);
    $this->fpdf->SetAuthor("MySiid's");
    $this->titulo($turma->fas_nome .' '. $turma->tur_nome, 'Relatório de Notas (Anual)');

    foreach ($alunos AS $aluno) {
      $nome = current($aluno);
      $nome = $nome['usu_nome'];
      $this->NomeAluno( $nome );
      foreach ($aluno AS $materia) {
        $this->ImprimeItem($materia['mat_nome'], $materia['nota_final']);
      }
    }

    $this->fpdf->header_title = "Relatório Anual gerado pelo MySiid's";
    $this->fpdf->AcceptPageBreak();
    $this->fpdf->Output( str_replace(' ', '_', $title).'.pdf' ,'D');
  }


  public function get_anual($tur_id)
  {
    $this->load->model('Turmas_model');
    $this->load->model('Lancamentos_model');
    $turma = $this->Turmas_model->get_turma($tur_id);
    $notas = $this->Lancamentos_model->get_turma_notas($tur_id);

    $title = "Relatório Anual {$turma->fas_nome} {$turma->tur_nome}";
    $this->fpdf->SetTitle($title);
    $this->fpdf->SetAuthor("MySiid's");
    $this->titulo("{$turma->fas_nome} {$turma->tur_nome}", 'Relatório de Notas (Anual)');

    if( !empty($notas) )
    {
      $alunos = array(); // Alunos q possuem nota
      // Gerando o PDF
      foreach ($notas AS $aluno) {
        $aux = current($aluno);
        $alunos[] = $aux['usu_id'];
        $this->NomeAluno( "{$aux['usu_nome']} ({$aux['usu_matricula']})" );

        foreach ($aluno AS $materia) {
          $this->ImprimeItem($materia['mat_nome'], $materia['nota_final']);
        }      
      }

      // Buscando os alunos que nao possuem notas
      $sem_nota = $this->alunos_sem_nota($tur_id, $alunos);
      if( !empty($sem_nota) )
      {
        $this->NomeAluno("Os alunos abaixo não possuem nota");

        $this->fpdf->SetFont('Arial','',10);
        foreach ($sem_nota AS $aluno) {
          $this->fpdf->MultiCell(90,5,utf8_decode("- {$aluno->usu_nome} ({$aluno->usu_matricula})"));
        }
      }

    }
    else
    {
      $this->fpdf->MultiCell(90,5,utf8_decode( "Não há notas para gerar o relatório" ));
    }

    $this->fpdf->header_title = "Relatório Anual gerado pelo MySiid's";
    $this->fpdf->AcceptPageBreak();
    $this->fpdf->Output( str_replace(' ', '_', $title).'.pdf' ,'D');
  }


  public function get_simplificado($tur_id, $bimestre)
  {
    $this->load->model('Turmas_model');
    $this->load->model('Lancamentos_model');
    $turma = $this->Turmas_model->get_turma($tur_id);
    $notas = $this->Lancamentos_model->get_turma_notas($tur_id, $bimestre);

    $title = "Relatório Simplificado {$bimestre}º Bimestre {$turma->fas_nome} {$turma->tur_nome}";
    $this->fpdf->SetTitle($title);
    $this->fpdf->SetAuthor("MySiid's");
    $this->titulo("{$turma->fas_nome} {$turma->tur_nome}", 'Relatório de Notas (Simplificado)', $bimestre);

    if( !empty($notas) )
    {
      $alunos = array(); // Alunos q possuem nota
      // Gerando o PDF
      foreach ($notas AS $aluno) {
        $aux = current($aluno);
        $alunos[] = $aux['usu_id'];
        $this->NomeAluno( "{$aux['usu_nome']} ({$aux['usu_matricula']})" );

        foreach ($aluno AS $materia) {
          $this->ImprimeItem($materia['mat_nome'], $materia['nota_final']);
        }      
      }

      // Buscando os alunos que nao possuem notas
      $sem_nota = $this->alunos_sem_nota($tur_id, $alunos);
      if( !empty($sem_nota) )
      {
        $this->NomeAluno("Os alunos abaixo não possuem nota");

        $this->fpdf->SetFont('Arial','',10);
        foreach ($sem_nota AS $aluno) {
          $this->fpdf->MultiCell(90,5,utf8_decode("- {$aluno->usu_nome} ({$aluno->usu_matricula})"));
        }
      }

    }
    else
    {
      $this->fpdf->MultiCell(90,5,utf8_decode( "Não há notas para gerar o relatório" ));
    }

    $this->fpdf->header_title = "Relatório Simplificado gerado pelo MySiid's";
    $this->fpdf->AcceptPageBreak();
    $this->fpdf->Output( str_replace(' ', '_', $title).'.pdf' ,'D');
  }


  public function get_completo($tur_id, $bimestre, $mat_id)
  {
    $this->load->model('Turmas_model');
    $this->load->model('Lancamentos_model');
    $this->load->model('Materias_model');
    $this->load->model('ListaExercicios_model');
    $turma = $this->Turmas_model->get_turma($tur_id);
    $materia = $this->Materias_model->get_materia($mat_id);

    $title = "Relatório Completo {$bimestre}º Bimestre {$turma->fas_nome} {$turma->tur_nome}";
    $this->fpdf->SetTitle($title);
    $this->fpdf->SetAuthor("MySiid's");
    $this->titulo_completo("{$turma->fas_nome} {$turma->tur_nome}", 'Relatório de Notas Completo', $materia->mat_nome);

    // Título das Colunas
    $header = array('Matrícula', 'Aluno', 'Nota');
    // Larguras das Colunas
    $larguras = array('20', '145', '25');

    $notas = $this->Lancamentos_model->get_notas_turma($tur_id, $bimestre, $mat_id);

    if( !empty($notas) )
    {
      $somatorio = array();

      /*
       * Exibindo os lançamentos */
        $lancamentos = array();
        // Separando por lançamento
        foreach ($notas AS $lan) {
          $lancamentos[$lan->lan_id][] = $lan;
        }
        foreach ($lancamentos AS $lan) {
          $aux = current($lan);
          $this->NomeLancamento("{$aux->lan_nome} - {$turma->fas_nome} {$turma->tur_nome} - {$bimestre}ª Bimestre");
          $this->CabTabela($header, $larguras);
          $this->fpdf->SetFont('Arial','',9);

          $alunos_com_nota = array(); // Alunos q possuem nota
          foreach ($lan AS $l) {
            $this->LinhaTabela(array($l->usu_matricula, $l->usu_nome, $l->not_nota), $larguras);
            $alunos_com_nota[] = $l->usu_id;

            // Faz a soma das notas
            if( !isset($somatorio[$l->usu_id]) )
            {
              $l = (array) $l;
              $l['nota_final'] = $l['not_nota'];
              $somatorio[$l['usu_id']] = $l;
            }
            else
            {
              $somatorio[$l->usu_id]['nota_final'] += $l->not_nota;
            }
          }

          // Buscando os alunos que nao possuem notas
          $sem_nota = $this->alunos_sem_nota($tur_id, $alunos_com_nota);
          if( !empty($sem_nota) )
          {
            $this->NomeLancamento("Os alunos abaixo não possuem nota");

            $this->fpdf->SetFont('Arial','',10);
            foreach ($sem_nota AS $aluno) {
              $this->fpdf->MultiCell(90,5,utf8_decode("- {$aluno->usu_nome} ({$aluno->usu_matricula})"));
            }
          }

          $this->QuebraPagina();
        }

      /*
       * Exibindo as Listas de exercicios */
        $this->NomeLancamento("Listas de exercicios - {$turma->fas_nome} {$turma->tur_nome} - {$bimestre}ª Bimestre");
        $this->CabTabela($header, $larguras);
        $this->fpdf->SetFont('Arial','',9);

        $alunos = $this->Turmas_model->get_turma_alunos($tur_id);
        $listas = array();
        foreach ($alunos AS $aluno) {
          $lista = $this->ListaExercicios_model->get_relacao_entregue( $aluno->usu_id , $bimestre  );

          $nota = (isset($lista[$mat_id]['lis_id'])) ? $lista[$mat_id]['lis_nota_final'] : 0;

          // Faz a soma das notas
          if( !isset($somatorio[$aluno->usu_id]['nota_final']) )
          {
            $aluno = (array) $aluno;
            $aluno['nota_final'] = $nota;
            $somatorio[$aluno['usu_id']] = $aluno;
          }
          else
          {
            $somatorio[$aluno->usu_id]['nota_final'] += $nota;
          }

          $aluno = (object) $aluno;
          // " {$lista[$mat_id]['entregue']} de {$lista[$mat_id]['total']}"
          $this->LinhaTabela(array($aluno->usu_matricula, $aluno->usu_nome, $nota), $larguras);
        }
        $this->QuebraPagina();

      /*
       * Exibindo a soma das notas */
        $this->NomeLancamento("Notas finais - {$turma->fas_nome} {$turma->tur_nome} - {$bimestre}ª Bimestre");
        $this->CabTabela($header, $larguras);
        $this->fpdf->SetFont('Arial','',9);

        foreach ($somatorio AS $aluno) {
          $nota = $this->Lancamentos_model->arredondamento_nota( $aluno['nota_final'] );

          $this->LinhaTabela(array($aluno['usu_matricula'], $aluno['usu_nome'], $nota), $larguras);
        }
        $this->QuebraPagina();

    }
    else
    {
      $this->fpdf->MultiCell(90,5,utf8_decode( "Não há notas para gerar o relatório" ));
    }

    // Exibindo
    $this->fpdf->header_title = "Relatório Completo gerado pelo MySiid's";
    $this->fpdf->AcceptPageBreak();
    $this->fpdf->Output( str_replace(' ', '_', $title).'.pdf' ,'D');
  }


  /**
   * Resgata os alunos que nao possuem nota, ignorando os que já tem
   * @param $tur_id -> ID da turma
   * @param $alunos -> array de id dos alunos
   *
   * @return Array de objetos
   */
  private function alunos_sem_nota($tur_id, $alunos)
  {
    $rs = $this->db->select('*')
                    ->from('usuario')
                    ->join('usuario_turma', 'usuario_turma.usu_id=usuario.usu_id')
                    ->where('usuario_turma.tur_id', $tur_id)
                    ->where_not_in('usuario.usu_id', $alunos)
                    ->get();

    return $rs->result();
  }

  /**
   * FUNÇÃO QUE IMPRIME O NOME DO ALUNO
   **/
  private function NomeAluno($NomeAluno)
  {
      $this->fpdf->Ln(4);
      $this->fpdf->SetFont('Arial','B',11);
      $this->fpdf->SetFillColor(190);
      $this->fpdf->MultiCell(90,5,utf8_decode($NomeAluno),0,'C',1);
  }

  /**
   * FUNÇÃO QUE IMPRIME UM ITEM NA LISTA
   **/
  private function ImprimeItem($Materia, $MediaAnual)
  {
      // Exibir Enunciado 1
      $this->fpdf->SetFont('Arial','',10);
      if($MediaAnual < 28)
      {
          $this->fpdf->SetTextColor(220,50,50);
          $this->fpdf->MultiCell(90,5,utf8_decode('****** '.$Materia.' = '.$MediaAnual));    
          $this->fpdf->SetTextColor(0);
      }
      else
      {
          $this->fpdf->MultiCell(90,5,utf8_decode($Materia.' = '.$MediaAnual));
      }
      
  }

  /**
   * FUNÇÃO QUE FAZ A QUEBRA DE PÁGINA E INICIA A PROVA DO ALUNO
   **/
  private function titulo($turma, $titulo, $bimestre='')
  {
      // Go back to first column
      $this->fpdf->SetCol(0);

      //inserindo a página de verso antes de iniciar a avaliação de outro aluno
      if($this->fpdf->PageNo()%2 != 0)
      {
          $this->fpdf->AddPage();
      }
      $this->fpdf->AddPage();

      $this->fpdf->SetFillColor(230);
      $this->fpdf->SetFont('Arial','B',10);
      $this->fpdf->MultiCell(90,5,utf8_decode($titulo),0,'C',1);
      $this->fpdf->MultiCell(90,5,utf8_decode("Turma: ".$turma),0,'C',1);
      if( !empty($bimestre) )
        $this->fpdf->MultiCell(90,5,utf8_decode($bimestre."º Bimestre"),0,'C',1);

      $this->fpdf->Ln(4);
  }



  /**
   * FUNÇÃO QUE GERA O CABECALHO DA TABELA
   **/
  private function CabTabela($data, $larguras)
  {
      $this->fpdf->Ln(4);
      $c = 0;
      foreach($data as $col)
      {
          $this->fpdf->SetFillColor(190);
          $this->fpdf->Cell($larguras[$c],7,utf8_decode($col),1,0,'C',true);
          $c ++;
      }
      $this->fpdf->Ln();
  }

    /**
     * FUNÇÃO QUE ADICIONA LINHA NA TABELA
     **/
    private function LinhaTabela($data, $larguras)
    {
        $c = 0;
        foreach($data as $col)
        {
            $this->fpdf->Cell($larguras[$c],6,utf8_decode($col),1);
            $c ++;
        }
        $this->fpdf->Ln();
    }

    /**
     * FUNÇÃO QUE IMPRIME O NOME DA MATÉRIA
     **/
    private function NomeLancamento($NomeLancamento)
    {
        $this->fpdf->Ln(4);
        $this->fpdf->SetFont('Arial','B',11);
        $this->fpdf->SetFillColor(190);
        $this->fpdf->MultiCell(190,5,utf8_decode($NomeLancamento),0,'C',1);
    }

    private function QuebraPagina()
    {
        if($this->fpdf->PageNo()%2 != 0)
        {
            $this->fpdf->AddPage();
        }
        $this->fpdf->AddPage();
    }

    /**
     * FUNÇÃO QUE IMPRIME O TITULO DO RELATORIO
     **/
    private function titulo_completo($turma, $titulo, $materia)
    {
        $this->fpdf->AddPage();
        $this->fpdf->SetFillColor(230);
        $this->fpdf->SetFont('Arial','B',10);
        $this->fpdf->MultiCell(190,5,utf8_decode($titulo),0,'C',1);
        $this->fpdf->MultiCell(190,5,utf8_decode("Turma: ".$turma),0,'C',1);
        $this->fpdf->MultiCell(190,5,utf8_decode($materia),0,'C',1);

        $this->fpdf->Ln(4);
    }
}
