<?php
defined('BASEPATH') OR exit('No direct script access allowed');

class Turmas_model extends CI_Model {

  public function __construct() {
    parent::__construct();
    $this->load->database();
  }


  /**
   * Cadastrar uma nova
   * @param $form -> Array com os dados do POST
   *
   * @return 'warning' -> Caso já exista
   * @return 'danger' -> Algum erro de processamento
   */
  public function cadastrar( $form )
  {
    if( !empty($form['nome']) )
    {
      $data = array('tur_nome'=> $form['nome'], 'fas_id'=>$form['fase']);

      // Verifica existencia
      $result = $this->db->get_where('turma', $data);
      $result = $result->result();

      if( $result )
      {
        return 'warning';
      }

      // Efetua o INSERT
      $sql = $this->db->insert_string('turma', $data );
      $result = $this->db->query( $sql );

      if( $result )
      {
        //Pegando o id da turma cadastrada
        $this->db->select_max('tur_id');
        $query = $this->db->get('turma');
        foreach ($query->result() as $row)
        {
          //direcionando para a página de edição
          header("location:../editar/".$row->tur_id);
        }
      } 
    }
    return "danger";
  }


  /**
   * Editar uma 
   * @param $id -> ID da  a ser alterada
   * @param $form -> Array com os dados do POST
   *
   * @return 'success' -> Matéria alterada com sucesso
   * @return 'warning' -> Caso  já exista
   * @return 'danger' -> Algum erro de processamento
   */
  public function editar( $id, $form )
  {

    $this->db->where('tur_id', $id);
    $this->db->delete('professor_turma');

    //Pegando as Matérias da Fase escolar
    $query = $this->db->get_where('turma', array('tur_id'=>$id));
    foreach ($query->result() as $row)
    {
      $data = array('fas_id'=> $row->fas_id);
    }

    $query = $this->db->get_where('fase_escolar_materia', $data);
    foreach ($query->result() as $row)
    {
      $data = array('mat_id'=> $row->mat_id, 'tur_id'=> $id, 'usu_id'=> $form[$row->mat_id]);
      //Efetua o INSERT na tabela intermediaria
      $sql = $this->db->insert_string('professor_turma', $data );
      $result = $this->db->query( $sql );
    }
    if( $result )
    {
      return 'success';
    } 
    else
    {
      return "danger";
    }


    //   $data = array('mat_nome'=> $form['nome']);

    //   // Verifica existencia
    //   $result = $this->db->get_where('materia', $data);
    //   $result = $result->result();

    //   if( $result )
    //   {
    //     return 'warning';
    //   }

    //   $result = $this->db->update('materia', $data, array('mat_id'=>$id));

    //   if( $result )
    //   {
    //     return 'success';
    //   } 
    
    // return "danger";
  }


  /**
   * Altera a relação do aluno com a turma
   * @param $usu_id (int) -> ID do aluno
   * @param $usu_id (array) -> Array contendo IDs de alunos
   */
  public function alterar_aluno_turma($usu_id, $tur_id)
  {
    $this->db->trans_start();

    // Esta vindo da edição do aluno
    if( !is_array($usu_id) )
    {
      $this->db->where_in('usu_id', $usu_id);
      $this->db->delete('usuario_turma');

      // Não foi selecionado nenhuma turma, ou seja, nao está em nenhuma relação
      if( empty($tur_id) )
      {
        $this->db->trans_complete();
        return 'success';
      }

      $usu_id = array( $usu_id );
    }
    else
    {
      // Quando esta sendo associado o(s) aluno(s) na turma,
      // Ela vai trazer todos os alunos no form($usu_id)
      // Por isso remove todos os alunos da turma, e insere novamente (atualizados)
      $this->db->where_in('tur_id', $tur_id);
      $this->db->delete('usuario_turma');
    }        

    // Na associação foi removido todos os alunos da turma
    // NAO OCORERÁ NA EDIÇÂO DO ALUNO
    // E nao há alunos pra inserir
    if( empty($usu_id) )
    {
      $this->db->trans_complete();
      return 'success';
    }

    // Criando um escopo para a inserção
    $data = array();
    foreach( $usu_id AS $id )
    {
      $data[] = array( 'usu_id' => $id, 'tur_id' => $tur_id );
    }

    // Insere novamente
    $this->db->insert_batch('usuario_turma', $data );
    if( $this->db->affected_rows() )
    {
      $this->db->trans_complete();
      return 'success';
    }
    
    return 'danger';
  }


  /**
   * Funcao utilizada como relatorio de relação da turma e quantidade aluno
   * @param $usu_id -> Referencia o professor. Faz com que retorne os alunos apenas da turma em que o ele ministra
   *
   * @return Array de objetos
   */
  public function get_alunos_por_turma( $usu_id = false )
  {
    $this->db->select('CONCAT(fase_escolar.fas_nome, " ", turma.tur_nome) AS `turma` , count(1) as total');
    // $this->db->select(' CONCAT(fase_escolar.fas_nome, ' / ', t.field2) AS `finalValue`  fase_escolar.fas_nome, turma.tur_nome, count(1) as total');
    $this->db->from('turma');
    $this->db->join('fase_escolar', 'fase_escolar.fas_id = turma.fas_id');
    $this->db->join('usuario_turma', 'usuario_turma.tur_id = turma.tur_id');
    if( $usu_id !== false )
    {
      $this->db->join('professor_turma', 'professor_turma.tur_id = turma.tur_id');
      $this->db->where('professor_turma.usu_id', $usu_id);
      
    }
    $this->db->group_by('turma.tur_id');
    $result = $this->db->get();

    if( $this->db->affected_rows() )
      return $result->result();
  }


  /**
   * Lista todas as turmas cadastradas
   * @param $not_empty -> Faz com que só retorne as turmas que possuam alunos
   *
   * @return Array de objetos com as turmas
   */
  public function get_turmas($not_empty = false)
  {
    $this->db->select('turma.*, fase_escolar.*');
    $this->db->from('turma');
    $this->db->join('fase_escolar', 'fase_escolar.fas_id = turma.fas_id');
    if( $not_empty !== false )
    {
      $this->db->join('usuario_turma', 'usuario_turma.tur_id = turma.tur_id');
      $this->db->group_by('turma.tur_id');
    }
    $turmas = $this->db->get();

    return $turmas->result();
  }


  /**
   * Lista as matérias da fase escolar
   * @param $id -> ID da turma a consultada
   *
   * @return (1) Objeto
   * @return (2) false
   */
  public function get_fase_escolar_materia( $id )
  {
    $query = $this->db->get_where('turma', array('tur_id'=>$id));
    $data = array();
    foreach ($query->result() as $row)
    {
      $data = array('fas_id'=> $row->fas_id);
    }
    $materias = $this->db->get_where('fase_escolar_materia', $data);

    if( $this->db->affected_rows() )
      return $materias->result();

    return false;
  }


  /**
   * Lista os registros da tabela intermediária na turma (professor_turma)
   *
   * @return Array de objetos com as matérias
   */
  public function get_professorturma($id)
  {
    $turma = $this->db->get_where('professor_turma', array('tur_id'=>$id));

    return $turma->result();
  }


  /**
   * Lista todos os registros da tabela intermediária (professor_turma)
   *
   * @return Array de objetos com as matérias
   */
  public function get_professoresturmas()
  {
    $turma = $this->db->get('professor_turma');

    return $turma->result();
  }


  /**
   * Baseado no ID da turma, serve para informar as materias e os professores de cada uma
   * @param $tur_id
   *
   * @return Array de Materias Com (array) professores
   */
  public function get_materias_fase($tur_id)
  {
    //
  }


  /**
   * Lista todas as turmas relacionadas (professor_turma) ao professor
   * @param $id -> ID do professor
   * @param $not_empty -> Para exibir apenas as turmas com alunos matriculados
   *
   * @return Array de objetos das turmas
   */
  public function get_turma_professor( $id, $not_empty = false ) {
    $this->db->select('*');
    $this->db->from('turma');
    $this->db->join('professor_turma', 'professor_turma.tur_id = turma.tur_id'); // Relacinando as turmas
    $this->db->join('fase_escolar', 'fase_escolar.fas_id = turma.fas_id'); // Relacionando a turma com a fase escolar

    if( $not_empty !== false )
    {
     $this->db->join('usuario_turma', 'usuario_turma.tur_id = turma.tur_id');
    }

    $this->db->where('professor_turma.usu_id', $id); // Usuario especifico
    $this->db->group_by('professor_turma.tur_id'); // Agrupando por turma (senao listaria cada materia que ele esta cadastrado)
    $query = $this->db->get();

    if( $this->db->affected_rows() )
      return $query->result();

    return false;
  }


  /**
   * Localiza a turma em que o aluno esta cadastrado
   * @param  $id -> ID do aluno
   *
   * @return Objeto da turma 
   */
  public function get_aluno_turma( $id )
  {
    $this->db->select('*');
    $this->db->from('turma');
    $this->db->join('usuario_turma', 'usuario_turma.tur_id = turma.tur_id'); // Relacinando as turmas
    $this->db->where('usuario_turma.usu_id', $id); // Usuario especifico
    $query = $this->db->get();

    if( $this->db->affected_rows() )
      return current($query->result());

    return false;
  }


  /**
   * Lista todos os alunos da turma
   * @param $tur_id -> ID da turma
   * @param $usu_id -> ID do professor (opcional)
   *
   * @return Array de objetos
   */
  public function get_turma_alunos( $tur_id, $usu_id='' )
  {
              $this->db->select('*');
              $this->db->from('usuario_turma');
              if( !empty($usu_id) )
              {
                // Esse JOIN faz com que o professor veja apenas as turmas referentes a ele
                $this->db->join('professor_turma', 'professor_turma.tur_id = usuario_turma.tur_id');
                $this->db->where('professor_turma.usu_id', $usu_id);
                $this->db->where('usuario.usu_id !=', $usu_id);
                $this->db->group_by('usuario.usu_id');
              }
              $this->db->join('usuario', 'usuario.usu_id = usuario_turma.usu_id');
              $this->db->where('usuario_turma.tur_id', $tur_id);
    $alunos = $this->db->get();

    return $alunos->result();
  }


  /**
   * Lista apenas uma turma
   * @param $id -> ID da turma a consultada
   * @param $usu_id -> ID do professor (opcional)
   *
   * @return (1) Objeto da materia
   * @return (2) false
   */
  public function get_turma( $id, $usu_id='' )
  {
    $this->db->select('*');
    $this->db->from('turma');
    $this->db->join('fase_escolar', 'fase_escolar.fas_id = turma.fas_id');
    if( !empty($usu_id) )
    {
      // Esse JOIN faz com que o professor veja apenas as turmas referentes a ele
      $this->db->join('professor_turma', 'professor_turma.tur_id = turma.tur_id');
    }
    $this->db->where('turma.tur_id', $id);
    $turma = $this->db->get();
    $turma = $turma->result();

    if( !empty($turma) )
      return current( $turma );

    return false;
  }


  /**
   * Pega a fase escolar da turma
   * @param $id -> ID da turma a consultada
   *
   * @return (1) Objeto da materia
   * @return (2) false
   */
  public function get_faseescolar( $id )
  {
    $fase = $this->db->get_where('turma', array('tur_id'=>$id));

    if( $this->db->affected_rows() )
    {
      $fase = current( $fase->result() );
      return $fase->fas_id;
    }

    return false;
  }


  /**
   * Pega ID da fase escolar baseado no ID da turma
   * @param $id -> ID da turma a consultada
   *
   * @return (1) Objeto da materia
   * @return (2) false
   */
  public function get_fase_escolar_id( $id )
  {
    $fase = $this->db->get_where('turma', array('tur_id'=>$id));

    if( $this->db->affected_rows() )
    {
      $fase = current( $fase->result() );
      return $fase->fas_id;
    }

    return false;
  }


  public function cadastrar_grade( $form, $tur_id )
  {
    $data = array(
      'tur_horario' => $form['arquivo']['file_name']
    );
    $result = $this->db->update('turma', $data, array('tur_id'=>$tur_id));

    if( $result )
    {
      return 'success';
    }
  }


  public function get_grade( $tur_id )
  {
    $query = $this->db->get_where('turma', array('tur_id'=>$tur_id));

    if( $this->db->affected_rows() )
      return current( $query->result() );

    return false;
  }

  public function get_turmas_professores(  )
  {
             $this->db->select('*');
             $this->db->from('turma');
             $this->db->join('professor_turma', 'professor_turma.tur_id = turma.tur_id'); // Relacionando as turmas
             $this->db->join('fase_escolar', 'fase_escolar.fas_id = turma.fas_id'); // Relacionando a turma com a fase escolar
             $this->db->join('materia', 'materia.mat_id = professor_turma.mat_id'); // Relacionando a turma/professor materias
             $this->db->join('usuario', 'usuario.usu_id = professor_turma.usu_id'); // Relacionando a turma/professor materias

             $this->db->order_by('fas_nome', 'asc');
             $this->db->order_by('tur_nome', 'asc');
    $query = $this->db->get();

    $relation = array();
    if( $this->db->affected_rows() )
    {      
      // Colocando em uma hierarquia TURMA -> PROFESSORES
      foreach ($query->result() AS $item)
      {
        $relation[ $item->fas_nome ][ $item->tur_nome ][] = $item;
      }
    }
      
    return $relation;
  }

  /**
   * Listar a relação de turmas x materias, na qual o professor está ministrando
   * Filtro adicional de apenas uma turma, passando o ID da turma com segunda parametro
   *
   * @param $usu_id -> ID do professor
   * @param $tur_id -> ID da turma (opcional)
   *
   * @return (1) Array com a relaçao FASE -> TURMA -> MATERIAS
   * @return (2) Matérias da turma especifica
   */
  public function get_professor_turma_materia( $usu_id, $tur_id='' )
  {
    $this->load->model('Materias_model');

    $query = $this->Materias_model->get_materia_professor( $usu_id, $tur_id );

    $relation = array();
    if( !empty($query) )
    {
      if( !empty($tur_id) )
        return current($query);
      
      // Colocando em uma hierarquia FASE -> TURMA -> MATERIAS
      foreach ($query AS $item)
      {
        $relation[ $item->fas_nome ][ $item->tur_nome ][] = $item;
      }
    }
      
    return $relation;
  }
}
