<?php
defined('BASEPATH') OR exit('No direct script access allowed');

class Usuarios_model extends CI_Model {

  public function __construct() {
    parent::__construct();
    $this->load->database();
  }


  /**
   * Efetua o login
   * @param $post = parametros do formulario
   * @return (1) Redirect para area do usuario
   * @return (2) Texto de mensagem de error
   */
  public function login( $post )
  {
    if( !empty($post['name']) && !empty($post['password']) )
    {
      // Consultar no banco de dados
      // Seta dados do usuario na sessao
      // redirecionar para a area especifica
      $sql  = "SELECT * FROM usuario u ";
      $sql .= "JOIN usuario_perfil up ON u.usuario_perfil_up_id = up.up_id ";
      $sql .= "WHERE usu_login=? AND usu_senha=MD5(?)";

      $result = $this->db->query($sql, array($post['name'], $post['password']));
      
      if( $this->db->affected_rows() )
      {
        $result = current($result->result());
        
        // Definições uteis para o Aluno
        if( $result->controller == 'aluno' )
        {
          $this->load->model('Turmas_model');
          $result = (array) $result;

          // Adicionando a grade horaria e o ID da turma
          $turma = $this->Turmas_model->get_aluno_turma($result['usu_id']);
          if( $turma )
          {
            $turma = $turma->tur_id;
            $grade = $this->Turmas_model->get_grade($turma);
            if( $grade )
              $grade = $grade->tur_horario;
            
            $result['tur_id'] = $turma;
            $result['grade_horaria'] = $grade;
          }
          else
          {
            return "Você não está matriculado em nenhuma turma.<br>Aguarde a finalização do seu cadastro.";
          }
        }

        $this->session->set_userdata('user', (object) $result );
        redirect( $result->controller );
      } else
      {
        return "Usuario ou senha incorretos";
      }

    }
    return "Nome de usuario ou senha estão vazios";
  }


  /**
   * Cadastrar um novo usuario
   * @param $form -> Array com os dados do POST
   * @param $perfil -> nome do perfil (controller)
   *
   * @return 'success' -> Usuario cadastrada com sucesso
   * @return 'warning' -> Caso matéria já exista
   * @return 'danger' -> Algum erro de processamento
   */
  public function cadastrar( $form, $perfil='' )
  {

    if( $perfil == 'aluno' )
    {
      return $this->cadastrar_aluno($form);
    }

    if( !empty($form['nome']) && !empty($form['senha']) && !empty($form['email']) && !empty($form['perfil']) )
    {
      // Verifica existencia
      $this->db->select('*');
      $this->db->from('usuario');
      $this->db->where('usu_login', $form['login']);
      $this->db->or_where('usu_email', $form['email']);
      $result = $this->db->get();
      $result = $result->result();      

      if( $result )
      {
        return 'warning';
      }

      // Efetua o INSERT
      $data = array(
        'usu_nome' => trim($form['nome']),
        'usu_login' => trim(strtolower($form['login'])),
        'usu_email' => trim(strtolower($form['email'])),
        'usu_senha' => md5($form['senha']),
        'usuario_perfil_up_id' => $form['perfil'],
      );

      // Verifica se existe foto
      if( !empty($form['foto']) )
      {
        $data['usu_foto'] = $form['foto']['file_name'];
      }
      
      $sql = $this->db->insert_string('usuario', $data );
      $result = $this->db->query( $sql );

      if( $result )
      {
        return 'success';
      } 
    }
    
    return "danger";
  }


  /**
   * Cadastrar um novo ALUNO
   * @param $form -> Array com os dados do POST
   *
   * @return 'success' -> Aluno cadastrada com sucesso
   * @return 'warning' -> Caso matéria já exista
   * @return 'danger' -> Algum erro de processamento
   */
  private function cadastrar_aluno( $form )
  {
    if( !empty($form['nome']) && !empty($form['matricula']) )
    {
      // Inicia uma 'transation' para que nada seja gravado na DB
      // Ate que todas as queries tenham sido efetuadas com sucesso
      // Insere aluno, atualiza login e insere relacao usuario_turma
      $this->db->trans_start();

      // Verifica existencia
      $this->db->select('*');
      $this->db->from('usuario');
      $this->db->where('usu_matricula', $form['matricula']);
      $this->db->or_where('usu_nome', $form['nome']);
      $result = $this->db->get();
      $result = $result->result();      

      if( $result )
      {
        return 'warning';
      }

      $perfil = $this->get_perfil( array('controller'=>'aluno') );
      $perfil = $perfil->up_id;

      // Dados do INSERT
      $data = array(
        'usu_nome' => trim($form['nome']),
        'usu_login' => '',
        'usu_email' => '',
        'usu_matricula' => $form['matricula'],
        'usu_senha' => md5($form['matricula']),
        'usuario_perfil_up_id' => $perfil,
      );

      // Verifica se existe foto
      if( !empty($form['foto']) )
      {
        $data['usu_foto'] = $form['foto']['file_name'];
      }
      
      // Efetua o insert
      $sql = $this->db->insert_string('usuario', $data );
      $result = $this->db->query( $sql );

      // Caso tenha dado errado
      if( !$result )
      {
        return 'danger';
      } 
      
      // Atualiza o login do usuario para o padrao (aluno.ID)
      $id_usuario = $this->db->insert_id();
      $this->db->set('usu_login', 'aluno.'.$id_usuario);
      $this->db->where('usu_id', $id_usuario);
      $result = $this->db->update('usuario');

      // Se não houve erro, e nao há relação com turma
      if( $result && empty($form['turma']) )
      {
        $this->db->trans_complete();
        return 'success';
      }
      elseif( !$result )
        return 'danger';

      // Insere a relacao entre usuario e turma (usuario_turma)
      $data = array(
        'usu_id' => $id_usuario,
        'tur_id' => $form['turma']
      );
      $sql = $this->db->insert_string('usuario_turma', $data );
      $result = $this->db->query( $sql );

      if( $result )
      {
        // Nao houve nenhum erro, gravas os comando no banco
        $this->db->trans_complete();
        return 'success';
      }

    }
    
    return "danger";
  }


  /**
   * Edita um usuario
   * @param $id -> ID do usuario a ser alterado
   * @param $form -> Array com os dados do POST
   *
   * @return 'success' -> Usuario cadastrada com sucesso
   * @return 'warning' -> Caso matéria já exista
   * @return 'danger' -> Algum erro de processamento
   */
  public function editar( $id, $form )
  {
    // Relacao dos inputs com as colunas do banco
    $relation = array(
      'nome' => 'usu_nome',
      'login' => 'usu_login',
      'senha' => 'usu_senha',
      'email' => 'usu_email',
      'perfil' => 'usuario_perfil_up_id',
      'turma' => 'tur_id',
      'matricula' => 'usu_matricula',
      'foto' => 'usu_foto',
    );

    // Prepara o formulario com as mesmas keys/colunas do banco
    foreach ($form AS $key => $value) {
      // Nova senha, precisa estar em md5
      if( $key=='senha' ) $value = md5($value);

      // A foto vem em array
      if( $key=='foto' ) $value = $value['file_name'];

      $new_key = $relation[$key];
      $form[ $new_key ] = $value;
      unset($form[$key]);
    }

    // Faz um merge dos dados para atualizar
    $usuario = (array) $this->get_usuario($id);
    $usuario = array_merge( $usuario, $form );
    // Remove os elementos duplicados no merge
    // $usuario = array_map("unserialize", array_unique(array_map("serialize", $usuario)));

    // Verifica se é aluno, pois o tratamento de update é diferenciado
    $perfil_aluno = $this->get_perfil( array('controller'=>'aluno') );    
    if( $usuario['usuario_perfil_up_id'] == $perfil_aluno->up_id )
    {
      return $this->editar_aluno( $id, $usuario );
    }
    
    // Verifica existencia
    $sql  = "SELECT * FROM usuario ";
    $sql .= "WHERE (usu_login = ? OR usu_email = ?) AND usu_id != ?";
    $result = $this->db->query($sql, array($usuario['usu_login'], $usuario['usu_email'], $id));
    $result = $result->result();

    if( $result )
    {
      return 'warning';
    }

    // Por conta do JOIN no get_usuario, removemos as colunas invalidas
    $removeKeys = array('up_id', 'apelido', 'controller');
    foreach($removeKeys as $key) {
      unset($usuario[$key]);
    }
         
    $result = $this->db->update('usuario', $usuario, array('usu_id'=>$id));

    if( $result )
    {
      return 'success';
    }
    else
    {
      return "danger";
    }    
  }


  /**
   *
   */
  private function editar_aluno( $id, $form )
  {
    // Inicia uma 'transation' para que nada seja gravado na DB
    // Ate que todas as queries tenham sido efetuadas com sucesso
    // Insere aluno, atualiza login e insere relacao usuario_turma
    $this->db->trans_start();

    // Verifica existencia
    $sql  = "SELECT * FROM usuario ";
    $sql .= "WHERE (usu_matricula = ? OR usu_nome = ?) AND usu_id != ?";
    $result = $this->db->query($sql, array($form['usu_matricula'], $form['usu_nome'], $id));
    $result = $result->result();

    if( $result )
    {
      return 'warning';
    }

    $aluno = $this->get_aluno( $id );

    // Verifica se houve alteração de turma
    if( $form['tur_id'] != $aluno->tur_id )
    {
      $this->load->model('Turmas_model');
      $result = $this->Turmas_model->alterar_aluno_turma($id, $form['tur_id']);

      if( !$result )
      {
        return 'danger';
      }
    }

    // Como o form ja veio preparado para o banco, e nao existe a coluna tur_id
    // na tabela usuario, removemos ela para nao dar erro na query
    unset($form['tur_id']);

    // Por conta do JOIN no get_usuario, removemos as colunas invalidas
    $removeKeys = array('up_id', 'apelido', 'controller');
    foreach($removeKeys as $key) {
      unset($form[$key]);
    }

    // Update !
    $result = $this->db->update('usuario', $form, array('usu_id'=>$id));

    if( $result )
    {
      // Nao houve nenhum erro, gravas os comando no banco
      $this->db->trans_complete();
      return 'success';
    }
    else
    {
      return "danger";
    }
  }


  /**
   * 
   */
  public function excluir( $id )
  {
    $this->db->trans_start();

    // Verifica se é aluno, pois precisa excluir o aluno de outros lugares
    // que não somente da tabela usuario
    $usuario = (array) $this->get_usuario($id);
    $perfil_aluno = $this->get_perfil( array('controller'=>'aluno') );    
    if( $usuario['usuario_perfil_up_id'] == $perfil_aluno->up_id )
    {
      // Removendo da turma
      $this->db->where('usu_id', $id);
      $this->db->delete('usuario_turma');
      if( !$this->db->affected_rows() )
        return 'danger';
    }

    // Verifica se é professor, pois precisa excluir o professor de outros lugares
    // que não somente da tabela usuario
    $usuario = (array) $this->get_usuario($id);
    $perfil_professor = $this->get_perfil( array('controller'=>'professor') );    
    if( $usuario['usuario_perfil_up_id'] == $perfil_professor->up_id )
    {
      // Removendo da turma
      $this->db->where('usu_id', $id);
      $this->db->delete('professor_turma');
      if( !$this->db->affected_rows() )
        return 'danger';
    }

    // Removendo do usuario
    $this->db->where('usu_id', $id);
    $this->db->delete('usuario');

    if( $this->db->affected_rows() )
    {
      $this->db->trans_complete();
      return 'success';
    }

    return 'danger';
  }


  /**
   * 
   */
  public function get_usuarios( $custom_where=array() ) {
             $this->db->select('*');
             $this->db->from('usuario');
             $this->db->join('usuario_perfil', 'usuario.usuario_perfil_up_id = usuario_perfil.up_id');
             if( !empty($custom_where) )
             {
               $this->db->where($custom_where);
             }
    $query = $this->db->get();

    if( $this->db->affected_rows() )
      return current( $query->result() );

    return false;
  }


  /**
   * 
   */
  public function get_usuario( $id, $custom_where=array() ) {
             $this->db->select('*');
             $this->db->from('usuario');
             $this->db->join('usuario_perfil', 'usuario.usuario_perfil_up_id = usuario_perfil.up_id');
             $this->db->where('usu_id', $id);
             if( !empty($custom_where) )
             {
               $this->db->where($custom_where);
             }
    $query = $this->db->get();

    if( $this->db->affected_rows() )
      return current( $query->result() );

    return false;
  }

  /**
   * Lista todos os administradores cadastrados
   *
   * @return Array de objetos com os administradores
   */
  public function get_administradores()
  {
    $this->db->select('*');
    $this->db->from('usuario');
    $this->db->join('usuario_perfil', 'usuario.usuario_perfil_up_id = usuario_perfil.up_id');
    $this->db->where('controller', 'admin');
    $query = $this->db->get();

    return $query->result();
  }

  /**
   * Lista todos os coordenadores cadastrados
   *
   * @return Array de objetos com os coordenadores
   */
  public function get_coordenadores()
  {
    $this->db->select('*');
    $this->db->from('usuario');
    $this->db->join('usuario_perfil', 'usuario.usuario_perfil_up_id = usuario_perfil.up_id');
    $this->db->where('controller', 'coordenador');
    $query = $this->db->get();

    return $query->result();
  }

  /**
   * Lista todos os coordenadores cadastrados
   * @param $join -> Efetua um join para retornar todos os dados do aluno como turma, etc
   *
   * @return Array de objetos com os coordenadores
   */
  public function get_alunos($join=false)
  {
    if( $join )
      $this->db->select('usuario.*, turma.*, fase_escolar.*');
    else
      $this->db->select('usuario.*');

    $this->db->from('usuario');
    $this->db->join('usuario_perfil', 'usuario.usuario_perfil_up_id = usuario_perfil.up_id');
    if( $join )
    {
      $this->db->join('usuario_turma', 'usuario.usu_id = usuario_turma.usu_id', 'left');
      $this->db->join('turma', 'turma.tur_id = usuario_turma.tur_id', 'left');
      $this->db->join('fase_escolar', 'fase_escolar.fas_id = turma.fas_id', 'left');
    }
    $this->db->where('usuario_perfil.controller', 'aluno');
    $query = $this->db->get();

    return $query->result();
  }


  /**
   * Lista todos os alunos cadastrados atraves da matricula
   * @param 
   *
   * @return Array de objetos com os alunos
   */
  public function get_alunos_by_matricula($matriculas=array(), $join=false)
  {
    if( !is_array($matriculas) )
      $matriculas = (array) $matriculas;

    $this->db->select('usuario.*');
    $this->db->from('usuario');
    $this->db->join('usuario_perfil', 'usuario.usuario_perfil_up_id = usuario_perfil.up_id');
    if( $join )
    {
      $this->db->join('usuario_turma', 'usuario.usu_id = usuario_turma.usu_id', 'left');
      $this->db->join('turma', 'turma.tur_id = usuario_turma.tur_id', 'left');
      $this->db->join('fase_escolar', 'fase_escolar.fas_id = turma.fas_id', 'left');
    }
    $this->db->where('usuario_perfil.controller', 'aluno');
    $this->db->where_in('usuario.usu_matricula', $matriculas);
    $query = $this->db->get();

    return $query->result();
  }


  /**
   * Lista apenas um aluno
   * @param $id -> ID do aluno a ser consultada
   *
   * @return (1) Objeto do aluno
   * @return (2) Array vazio
   */
  public function get_aluno( $id )
  {
    $this->db->select('usuario.*, usuario_turma.tur_id, usuario_perfil.controller');
    $this->db->from('usuario');
    $this->db->join('usuario_perfil', 'usuario.usuario_perfil_up_id = usuario_perfil.up_id');
    $this->db->join('usuario_turma', 'usuario.usu_id = usuario_turma.usu_id', 'left');
    $this->db->where('controller', 'aluno');
    $this->db->where('usuario.usu_id', $id);
    $query = $this->db->get();
    $query = $query->result();

    if( !empty($query) )
      return current( $query );

    return false;
  }

  /**
   * Lista todos os professores cadastrados
   *
   * @return Array de objetos com os coordenadores
   */
  public function get_professores()
  {
    $this->db->select('*');
    $this->db->from('usuario');
    $this->db->join('usuario_perfil', 'usuario.usuario_perfil_up_id = usuario_perfil.up_id');
    $this->db->where('controller', 'professor');
    $query = $this->db->get();

    return $query->result();
  }


  /**
   * Lista apenas um perfil
   * @param $data -> Array contento os "WHERES" da consulta
   *
   * @return (1) Objeto da materia
   * @return (2) false
   */
  public function get_perfil( $data ) {    
    $result = $this->db->get_where('usuario_perfil', $data);
    $result = $result->result();

    if( !empty($result) )
      return current( $result );

    return false;
  }

  /**
   * Lista a turma do usuario
   * @param $data -> Array contento os "WHERES" da consulta
   *
   * @return (1) Objeto da materia
   * @return (2) false
   */
  public function get_turma( $id ) 
  {    
    $data = array('usu_id' => $id, );

    $query = $this->db->get_where('usuario_turma', $data);

    if( !empty($query) )
    {
      foreach ($query->result() as $key)
      {
        $tur_id = $key->tur_id;
        return $tur_id;
      }
    }
    return false;
  }

  /**
   * Lista todos os perfils de usuario
   * @return Array de Objects dos perfils 
   */
  public function get_perfils($custom_where=array()) {
             $this->db->select('*');
             $this->db->from('usuario_perfil');
             if( !empty($custom_where) )
             {
               $this->db->where($custom_where);
             }
    $query = $this->db->get();

    return $query->result();
  }

}
