<?php
defined('BASEPATH') OR exit('No direct script access allowed');

class Admin extends MY_Controller {


  /**
   * Initialize template and model
   */
  public function __construct()
  {
    parent::__construct();

    $this->twiggy->title('Administrador');
  }


  /**
   * Home page
   */
  public function index()
  {
    $this->load->model('Turmas_model');
    $this->load->model('Avaliacoes_model');
    $data = array();
    $data['alunos_por_turma'] = $this->Turmas_model->get_alunos_por_turma();
    $data['acompanhamento_questoes'] = $this->Avaliacoes_model->get_acompanhamento();

    $this->twiggy->set($data, null);
    $this->twiggy->display('comum/index_resumo_atividades');
  }


  /**
   * Manter Matérias
   */
  public function materias($action="", $id="")
  {
    $data = array();
    $this->load->model('Materias_model');

    if( $action=='cadastrar' )
    {
      // Foi submetido um form para a propia pagina
      $form = $this->input->post();
      if( !empty($form) )
      {
        $data['result_cadastrar'] = $this->Materias_model->cadastrar($form);
        
        $this->twiggy->set($data, true);
      }
      
      $this->twiggy->display('admin/materias_cadastrar');
    }
    else if( $action=='editar' && !empty($id) )
    {
      // Foi submetido um form para a propia pagina
      $form = $this->input->post();
      if( !empty($form) )
      {
        $data['result_editar'] = $this->Materias_model->editar($id, $form);
        $this->twiggy->set($data, true);
      }
      // Final da parte que realmente faz a edicao
      // -----------------------------------------

      // Resgatando os dados da materia
      $materia = $this->Materias_model->get_materia( $id );
      if( $materia==false )
      {
        $data['result_editar'] = 'danger';
        $this->twiggy->set($data, true);
      }
      else
      {
        $this->twiggy->set('materia', $materia);
      }

      $this->twiggy->display('admin/materias_editar');
    }
    else
    {
      //Pegando as Matérias
      $materias = $this->Materias_model->get_materias();
      $this->twiggy->set('materias', $materias);

      $this->twiggy->display('admin/materias');
    }
  }


  /**
   * Manter Fases Escolares
   */
  public function fases_escolares($action="", $id="")
  {
    $data = array();
    $this->load->model('FasesEscolares_model');

    if( $action=='cadastrar' )
    {
      // Foi submetido um form para a propia pagina
      $form = $this->input->post();
      if( !empty($form) )
      {
        $data['result_cadastrar'] = $this->FasesEscolares_model->cadastrar($form);
        
        $this->twiggy->set($data, true);
      }

      $materias = $this->FasesEscolares_model->get_materias();

      $this->twiggy->set('materias', $materias);
      
      $this->twiggy->display('admin/fases_escolares_cadastrar');
    }
    else if( $action=='editar' && !empty($id) )
    {
      // Foi submetido um form para a propia pagina
      $form = $this->input->post();
      if( !empty($form) )
      {
        $data['result_editar'] = $this->FasesEscolares_model->editar($id, $form);
        $this->twiggy->set($data, true);
      }
      // Final da parte que realmente faz a edicao
      // -----------------------------------------

      // Resgatando os dados da fase escolar
      $faseescolar = $this->FasesEscolares_model->get_faseescolar( $id );

      if( $faseescolar==false )
      {
        $data['result_editar'] = 'danger';
        $this->twiggy->set($data, true);
      }
      else
      {
        $this->twiggy->set('faseescolar', $faseescolar);
      }

      //Pegando as Matérias
      $materias = $this->FasesEscolares_model->get_materias();
      $this->twiggy->set('materias', $materias);

      //Pegando as Associações
      $fasesescolares = $this->FasesEscolares_model->get_fasesescolares_materias( $id );

      // Pega apenas os ID's das utilizadas nessa fase escolar
      $fases_atuais = array();
      if( $fasesescolares )
      {
        foreach( $fasesescolares AS $fase )
        {
          $fases_atuais[] = $fase->mat_id;
        }
      }

      $this->twiggy->set('fases_atuais', $fases_atuais);

      $this->twiggy->display('admin/fases_escolares_editar');
    }
    else
    {
      $fasesescolares = $this->FasesEscolares_model->get_fasesescolares();
      $this->twiggy->set('fasesescolares', $fasesescolares);
      $this->twiggy->display('admin/fases_escolares');
    }
  }


  /**
   * Manter Usuarios
   */
  public function usuarios($action='', $id='')
  {
    $data = array();
    $this->load->model('Usuarios_model');

    if( $action=='cadastrar' )
    {
      // Foi submetido um form para a propia pagina
      $form = $this->input->post();
      if( !empty($form) )
      {
        // Faz o cadastro e upload da imagem
        if ( !empty($_FILES['foto']['name']) )
        {
          // Carrega as configs de upload
          $config = $this->config->item('mysiids');
          $this->load->library('upload', $config['usuario_foto_upload']);

          if ( !$this->upload->do_upload('foto') )
          {
            $data['result_cadastrar'] = 'imagem_error';
          }
          else
          {
            $form['foto'] = $this->upload->data();
            $data['result_cadastrar'] = $this->Usuarios_model->cadastrar($form);
          }

        }
        else
        {
          // Apenas o cadastro, sem imagem
          $data['result_cadastrar'] = $this->Usuarios_model->cadastrar($form);
        }
        
        $this->twiggy->set($data, true);
      }

      // Para o select de perfil
      $perfils = $this->Usuarios_model->get_perfils(array('controller !='=>'aluno'));
      $this->twiggy->set('perfils', $perfils);
      
      $this->twiggy->display('admin/usuarios_cadastrar');
    }
    else if( $action=='editar' && !empty($id) )
    {
      // Foi submetido um form para a propia pagina
      $form = $this->input->post();
      if( !empty($form) )
      {
        // Faz o cadastro e upload da imagem
        if ( !empty($_FILES['foto']['name']) )
        {
          // Carrega as configs de upload
          $config = $this->config->item('mysiids');
          $this->load->library('upload', $config['usuario_foto_upload']);

          if ( !$this->upload->do_upload('foto') )
          {
            $data['result_editar'] = 'imagem_error';
          }
          else
          {
            $form['foto'] = $this->upload->data();
            $data['result_editar'] = $this->Usuarios_model->editar($id, $form);
          }

        }
        else
        {
          // Apenas o cadastro, sem imagem
          $data['result_editar'] = $this->Usuarios_model->editar($id, $form);
        }
        
        $this->twiggy->set($data, true);
      }
      // Final da parte que realmente faz a edicao
      // -----------------------------------------

      // Para o select de perfil
      $perfils = $this->Usuarios_model->get_perfils(array('controller !='=>'aluno'));
      $this->twiggy->set('perfils', $perfils);

      // Resgatando os dados do usuario, nao permitindo q sejam alunos
      $usuario = $this->Usuarios_model->get_usuario( $id, array('usuario_perfil.controller !='=>'aluno') );
      if( $usuario==false )
      {
        $data['result_editar'] = 'danger';
        $this->twiggy->set($data, true);
      }
      else
      {
        $this->twiggy->set('usuario', $usuario);
      }

      $this->twiggy->display('admin/usuarios_editar');
    }
    else if( $action=='excluir' && !empty($id) )
    {

      $data['result_excluir'] = $this->Usuarios_model->excluir($id);
      $this->twiggy->set($data, true);
      $this->twiggy->display('admin/usuarios_excluir');
    }
    else
    {
      $usuarios = array(
        'Administradores' => $this->Usuarios_model->get_administradores(),
        'Coordenadores'   => $this->Usuarios_model->get_coordenadores(),
        'Professores'     => $this->Usuarios_model->get_professores(),
      );

      $this->twiggy->set('usuarios', $usuarios);
      $this->twiggy->display('admin/usuarios');
    }
  }


  /**
   * Configuração
   */
  public function configuracao($action="")
  {
    $data = array();
    $this->load->model('Configuracao_model');

    if($action == "confirma_resetar")
    {
      // $form = $this->input->post();
      // if( !empty($form) )
      // {
      //   $data['result_cadastrar'] = $this->Configuracao_model->resetar($form);
        
      //   $this->twiggy->set($data, true);
      // }

      // $this->twiggy->display('admin/configuracao_confirma_reset');
    }
    else
    {
      $form = $this->input->post();
      if( !empty($form) )
      {
        $data['result_cadastrar'] = $this->Configuracao_model->atualizar($form);
        
        $this->twiggy->set($data, true);
      }
      if(isset($data['result_cadastrar']) && $data['result_cadastrar'] == 'prosseguir')
      {
        $this->twiggy->display('admin/configuracao_confirma_reset');
      }

      //Pegando as configurações
      $con = $this->Configuracao_model->get_con();
      $this->twiggy->set('con', $con);

      $this->twiggy->display('admin/configuracao');
    }
  }
}
