<?php
defined('BASEPATH') OR exit('No direct script access allowed');

class Questoes_model extends CI_Model {

  public function __construct() {
    parent::__construct();
    $this->load->database();
  }

  /**
   * Cadastrar uma nova 
   * @param $form -> Array com os dados do POST
   *
   * @return 'success' -> cadastrada com sucesso
   * @return 'warning' -> Caso já exista
   * @return 'danger' -> Algum erro de processamento
   */
  public function cadastrar( $form )
  {
    if( !empty($form['enunciado1']) )
    {
      $this->db->trans_start();

      $discursiva = true;

      // Verificando se é objetiva
      if($form['discursiva'] == "N")
      {
        // Verificando se as alternativas estão vazias
        if($form['correta'] == '' || $form['errada1'] == '' || $form['errada2'] == '' || $form['errada3'] == '' || $form['errada4'] == '')
        {
          return 'dangeralt';
        }
        // Verificando se há alternativas iguais
        if($form['errada1'] == $form['correta'] || $form['errada2'] == $form['correta'] || $form['errada3'] == $form['correta'] || $form['errada4'] == $form['correta'])
        {
          return 'dangeraltig';
        }
        $discursiva = false;
      }

      $data = array(
        'mat_id'            => $form['materia'],
        'que_discursiva'    => $discursiva,
        'que_enunciado1'    => $form['enunciado1'],
        'que_enunciado2'    => $form['enunciado2']);

      // Inclui a imagem
      if( !empty($form['imagem']) )
        $data['que_imagem'] = $form['imagem']['file_name'];

      // Efetua o INSERT
      $sql = $this->db->insert_string('questao', $data );
      $result = $this->db->query( $sql );

      if( $result )
      {
        //Pegando o id da avaliacao cadastrada
        $this->db->select_max('que_id');
        $query = $this->db->get('questao');
        foreach ($query->result() as $row)
        {
          $que_id = $row->que_id;
        }
        if( !$discursiva )
        {
          $data = array(
            array('que_id' => $que_id, 'alt_descricao' => $form['correta'], 'alt_correta' => '1'),
            array('que_id' => $que_id, 'alt_descricao' => $form['errada1'], 'alt_correta' => '0'),
            array('que_id' => $que_id, 'alt_descricao' => $form['errada2'], 'alt_correta' => '0'),
            array('que_id' => $que_id, 'alt_descricao' => $form['errada3'], 'alt_correta' => '0'),
            array('que_id' => $que_id, 'alt_descricao' => $form['errada4'], 'alt_correta' => '0')
          );
          $this->db->insert_batch('questao_alternativa', $data );
          if( !$this->db->affected_rows() )
            return 'danger';
        }
      }

      $this->db->trans_complete();
    }
    // direcionando para a parte 2
    header("location:../cadastrar-2/".$que_id);
    return "danger";
  }

  /**
   * Continuação do Cadastro
   * @param $form -> Array com os dados do POST
   *
   * @return 'success' -> cadastrada com sucesso
   * @return 'warning' -> Caso já exista
   * @return 'danger' -> Algum erro de processamento
   */
  public function cadastrar_2( $form, $id_questao )
  {
    // Atualizar a questao
    if(isset($form['linhas']))
    { 
      $data = array('que_linhas'=> $form['linhas']);
    }
    else
    {
      $data = array('que_linhas'=> 0); 
    }

    $result = $this->db->update('questao', $data, array('que_id'=>$id_questao));
    if(!$result)
      return 'danger';

    // Avaliações
    if(isset($form['ava']))
    {
      $this->load->model('Avaliacoes_model');
      foreach ($form['ava'] as $key) 
      {
        // Atualizar a tabela intermediaria
        $data = array('que_id'=> $id_questao);

        $result = $this->db->update('avaliacao_questao', $data, array('aq_id'=>$key));
        if(!$result)
          return 'danger';
        $this->Avaliacoes_model->update_status_questao_avaliacao($key);
      }
    }
    
    // PPD
    if(isset($form['ppd']))
    {
      $this->load->model('Avaliacoes_model');
      foreach ($form['ppd'] as $key) 
      {
        // Atualizar a tabela intermediaria
        $data = array('que_id'=> $id_questao);

        $result = $this->db->update('ppd_questao', $data, array('pq_id'=>$key));
        if(!$result)
          return 'danger';
        $this->Avaliacoes_model->update_status_questao_ppd($key);
      }
    }

    // Simulados
    if(isset($form['sim']))
    {
      $this->load->model('Simulados_model');
      foreach ($form['sim'] as $key) 
      {
        // Atualizar a tabela intermediaria
        $data = array('que_id'=> $id_questao);

        $result = $this->db->update('simulado_questao', $data, array('sq_id'=>$key));
        if(!$result)
          return 'danger';
        $this->Simulados_model->update_status_questao_simulado($key);
      }
    }
    return 'success';
  }

  
  /**
   * Editar
   * @param $form -> Array com os dados do POST
   *
   * @return 'success' -> cadastrada com sucesso
   * @return 'warning' -> Caso já exista
   * @return 'danger' -> Algum erro de processamento
   */
  public function editar( $form, $id )
  {
    if(isset($form['linhas']))
    {
      $data = array('que_enunciado1'=> $form['enunciado1'], 'que_enunciado2'=> $form['enunciado2'], 'que_linhas'=> $form['linhas']);
    }
    else
    {
      $data = array('que_enunciado1'=> $form['enunciado1'], 'que_enunciado2'=> $form['enunciado2']);
      //Pegando as Alternativas
      $alternativas = $this->Questoes_model->get_alternativas( $id );
      foreach ($alternativas as $key) 
      {
        $data_alt = array('alt_descricao'=> $form[$key->alt_id]);
        $result = $this->db->update('questao_alternativa', $data_alt, array('alt_id'=> $key->alt_id));
        if(!$result)
        {
          return 'danger';
        }
      }
    }

    // Inclui a imagem
      if( !empty($form['imagem']) )
        $data['que_imagem'] = $form['imagem']['file_name'];

    $result = $this->db->update('questao', $data, array('que_id'=> $id));

    if( $result )
    {
      return 'success';
    } 
    return "danger";
  }

  /**
   * Inclui uma nova questão
   * @param $form -> Array com os dados do POST
   *
   * @return 'success' -> cadastrada com sucesso
   * @return 'warning' -> Caso já exista
   * @return 'danger' -> Algum erro de processamento
   */
  public function incluir( $form, $id )
  {
    // if(isset($form['discursiva']))
    // {
    //   $discursiva = 1;
    // }
    // else
    // {
    //   $discursiva = 0;
    // }
    // if($form['mat_id'] == 'null')
    // {
    //   return 'danger';
    // }
    // $data = array('ava_id'=> $id, 'aq_discursiva'=> $discursiva, 'aq_anulada'=> '0', 'mat_id'=> $form['mat_id']);

    // $sql = $this->db->insert_string('avaliacao_questao', $data );
    // $result = $this->db->query( $sql );

    // if( $result )
    // {
    //   return 'successn';
    // } 
    // return "danger";
  }

  /**
   * Lista apenas uma questao
   * @param $id -> ID da turma a consultada
   *
   * @return (1) Objeto da materia
   * @return (2) false
   */
  public function get_questao( $id )
  {
              $this->db->select('*');
              $this->db->from('questao');
              $this->db->join('materia', 'questao.mat_id = materia.mat_id');
              $this->db->where('questao.que_id', $id);
    $query = $this->db->get();

    if( $this->db->affected_rows() )
      return current( $query->result() );
    return false;
  }

  /**
   * Lista apenas uma questao
   * @param $id -> ID da turma a consultada
   *
   * @return (1) Objeto da materia
   * @return (2) false
   */
  public function get_alternativas( $id )
  {
              $this->db->select('*');
              $this->db->from('questao_alternativa');
              $this->db->where('que_id', $id);
    $query = $this->db->get();

    return $query->result();

    return false;
  }

  /**
   * Lista todas as avaliações
   *
   * @return Array de objetos
   */
  public function get_avaliacoes( $bimestre )
  {
    // $avaliacoes = $this->db->get_where('avaliacao', array('ava_bimestre'=>$bimestre));
    // return $avaliacoes->result();
  }

  public function get_total_cadastradas_professor($usu_id)
  {
    $this->db->select('*');
    $this->db->from('avaliacao_questao');

    
      $this->db->join('avaliacao', 'avaliacao.ava_id = avaliacao_questao.ava_id');
      $this->db->join('professor_turma', 'professor_turma.tur_id = avaliacao.tur_id');
      $this->db->join('materia', 'materia.mat_id = professor_turma.mat_id AND avaliacao_questao.mat_id=materia.mat_id');
      $this->db->where('avaliacao_questao.que_id IS NOT NULL');
      $this->db->where('professor_turma.usu_id', $usu_id);
    
    $rs = $this->db->get();

    if( $this->db->affected_rows() )
    {
      $ava = array();
      foreach ($rs->result() AS $questao) {
        $ava[ $questao->ava_id ][] = $questao;
      }

      return $ava;
    }

    return;
  }

  /**
   * Lista todas as questoes da tabela intermediaria
   *
   * @return Array de objetos
   */
  public function get_questoes( $id )
  {
    // $sql  = "SELECT * FROM avaliacao_questao aq ";
    // $sql .= "JOIN materia m ON aq.mat_id = m.mat_id ";
    // $sql .= "WHERE ava_id=?";

    // $result = $this->db->query($sql, array($id));
    // return $result->result();
  }

  /**
   * Excluir
   */
  public function excluir( $id )
  {
    // $q = $this->db->get_where('avaliacao_questao', array('aq_id'=>$id));
    // foreach ($q->result() as $key) 
    // {
    //   $ava_id = $key->ava_id;
    // }

    // $this->db->where('aq_id', $id);
    // $this->db->delete('avaliacao_questao');
    // if( $this->db->affected_rows() )
    // {
    //   //direcionando para a parte 2
    //   header("location:../editar/".$ava_id); 
    // }
    // return 'danger';
  }

  /**
   * Muda a opção discursiva da questao
   */
  public function alterarquestao( $id )
  {
    // $q = $this->db->get_where('avaliacao_questao', array('aq_id'=>$id));
    // foreach ($q->result() as $key) 
    // {
    //   $ava_id = $key->ava_id;
    //   if($key->aq_discursiva == 0)
    //   {
    //     $data = array('aq_discursiva'=> 1);
    //   }
    //   else
    //   {
    //     $data = array('aq_discursiva'=> 0);
    //   }
    // }
    
    // $result = $this->db->update('avaliacao_questao', $data, array('aq_id'=>$id));
    // if( $result )
    // {
    //   //direcionando para a parte 2
    //   header("location:../editar/".$ava_id); 
    // }
    // return 'danger';
  }

  /**
   * Desassocia uma questao
   */
  public function desassociar( $id , $tabela )
  {
    if($tabela == 'a')
    {
      $q = $this->db->get_where('avaliacao_questao', array('aq_id'=>$id));
      foreach ($q->result() as $key) 
      {
        $ava_id = $key->ava_id;
      }

      $data = array('que_id'=> null);
      $result = $this->db->update('avaliacao_questao', $data, array('aq_id'=>$id));
      if( $result )
      {
        $this->db->update('avaliacao', array('ava_status'=> 1), array('ava_id'=>$ava_id));
        //direcionando para a parte 2
        header("location:../../avaliacoes/".$ava_id."/"); 
      }
      return 'danger';
    }
    elseif($tabela == 's')
    {
      $q = $this->db->get_where('simulado_questao', array('sq_id'=>$id));
      foreach ($q->result() as $key) 
      {
        $sim_id = $key->sim_id;
      }

      $q = $this->db->get_where('simulado', array('sim_id'=>$sim_id));
      foreach ($q->result() as $key) 
      {
        $sim_bimestre = $key->sim_bimestre;
        $tur_id = $key->tur_id;
      }

      $data = array('que_id'=> null);
      $result = $this->db->update('simulado_questao', $data, array('sq_id'=>$id));
      if( $result )
      {
        //direcionando para a parte 2
        header("location:../../simulados/".$tur_id."/".$sim_bimestre."/"); 
      }
      return 'danger';
    }
    elseif($tabela == 'p')
    {
      $q = $this->db->get_where('ppd_questao', array('pq_id'=>$id));
      foreach ($q->result() as $key) 
      {
        $ppd_id = $key->ppd_id;
      }

      $q = $this->db->get_where('ppd', array('ppd_id'=>$ppd_id));
      foreach ($q->result() as $key) 
      {
        $ppd_bimestre = $key->ppd_bimestre;
        $tur_id = $key->tur_id;
      }

      $data = array('que_id'=> null);
      $result = $this->db->update('ppd_questao', $data, array('pq_id'=>$id));
      if( $result )
      {
        //direcionando para a parte 2
        header("location:../../ppd/".$tur_id."/".$ppd_bimestre."/"); 
      }
      return 'danger';
    }
  }

  /**
   * Anular e Revalidar Questão
   */
  public function anularquestao( $id, $tabela )
  {
    if($tabela == 'a')
    {
      $q = $this->db->get_where('avaliacao_questao', array('aq_id'=>$id));
      foreach ($q->result() as $key) 
      {
        $ava_id = $key->ava_id;
        if($key->aq_anulada == 0)
        {
          $data = array('aq_anulada'=> 1);
        }
        else
        {
          $data = array('aq_anulada'=> 0);
        }
      }
      
      $result = $this->db->update('avaliacao_questao', $data, array('aq_id'=>$id));
      if( $result )
      {
        //direcionando para a parte 2
        header("location:../../avaliacoes/".$ava_id."/"); 
      }
      return 'danger';
    }
    elseif ($tabela == 's') 
    {
      $q = $this->db->get_where('simulado_questao', array('sq_id'=>$id));
      foreach ($q->result() as $key) 
      {
        $sim_id = $key->sim_id;
        if($key->sq_anulada == 0)
        {
          $data = array('sq_anulada'=> 1);
        }
        else
        {
          $data = array('sq_anulada'=> 0);
        }
        echo "<pre>";
        print_r($key);
        echo "</pre>";
      }

      $q = $this->db->get_where('simulado', array('sim_id'=>$sim_id));
      foreach ($q->result() as $key) 
      {
        $sim_bimestre = $key->sim_bimestre;
        $tur_id = $key->tur_id;
      }

      $result = $this->db->update('simulado_questao', $data, array('sq_id'=>$id));
      if( $result )
      {
        //direcionando para a parte 2
        header("location:../../simulados/".$tur_id."/".$sim_bimestre."/"); 
      }
      return 'danger';
    }
  }
}
