<?php
defined('BASEPATH') OR exit('No direct script access allowed');

class Simulados_model extends CI_Model {

  public function __construct() {
    parent::__construct();
    $this->load->database();
  }

  /**
   * Cadastrar uma nova 
   * @param $form -> Array com os dados do POST
   *
   * @return 'success' -> cadastrada com sucesso
   * @return 'warning' -> Caso já exista
   * @return 'danger' -> Algum erro de processamento
   */
  public function cadastrar( $form )
  {
    if( !empty($form['dataaplicacao']) )
    {
      $this->load->model('Configuracao_model');
      $this->load->model('Turmas_model');

      //Pegando o bimestre
      $bimprova = $this->Configuracao_model->get_bimestredata($form['dataaplicacao']);

      if($bimprova == "N")
      {
        return 'warning';
      }

      //Verificando a existencia
      $simulado = $this->db->get_where('simulado', array('sim_bimestre'=>$bimprova));
      $simulado = $simulado->result();

      if( !empty($simulado) )
        return 'dangerbim';

      //Pegando as turmas
      $turmas = $this->Turmas_model->get_turmas();
      foreach ($turmas as $turma) 
      {
        $data = array('tur_id'=> $turma->tur_id, 'sim_dataAplicacao'=>$form['dataaplicacao'], 'sim_dataLimiteRealizacao'=> $form['datarealizacao'], 'sim_dataLimiteCadastroQuestoes'=>$form['datacadastro'], 'sim_status'=>'1', 'sim_bimestre'=>$bimprova);

        //Pegando as Matérias da fase escolar
        $materias = $this->Turmas_model->get_fase_escolar_materia( $turma->fas_id );
        $id_materias = array();
        if( $materias )
        {
          foreach( $materias AS $reg )
          {
            $id_materias[] = $reg->mat_id;
          }
        }

        // Efetua o INSERT
        $sql = $this->db->insert_string('simulado', $data );
        $result = $this->db->query( $sql );

        if( $result )
        {
          //Pegando o id da avaliacao cadastrada
          $this->db->select_max('sim_id');
          $query = $this->db->get('simulado');
          foreach ($query->result() as $row)
          {
            $sim_id = $row->sim_id;
          }
          //Cadastrar as questoes na tabala intermediaria

          //Pegando as materias
          $materias = $this->Materias_model->get_materias();
          foreach ($materias as $row) 
          {
            if(in_array($row->mat_id, $id_materias))
            {
              $anulada = false;
              
              $data2 = array('sim_id'=> $sim_id, 'sq_anulada'=> $anulada, 'mat_id'=> $row->mat_id);
              $qtd = 5;
              $i = 1;
              while ( $i <= $qtd) 
              {
                // Efetua o INSERT
                $sql = $this->db->insert_string('simulado_questao', $data2 );
                $result = $this->db->query( $sql );
                if(!$result)
                {
                  return 'danger';
                }
                $i++;
              }
            }
          } 
        }
      }
      return 'success';
    }
    return "danger";
  }

  /**
   * Editar
   * @param $form -> Array com os dados do POST
   *
   * @return 'success' -> cadastrada com sucesso
   * @return 'warning' -> Caso já exista
   * @return 'danger' -> Algum erro de processamento
   */
  public function editar( $form, $id )
  {
    $data = array('sim_dataAplicacao'=> $form['dataaplicacao'], 'sim_dataLimiteCadastroQuestoes'=> $form['datalimitecadastro'], 'sim_dataLimiteRealizacao'=> $form['datalimiterealizacao']);

    $result = $this->db->update('simulado', $data, array('sim_id'=>$id));

    if( $result )
    {
      return 'success';
    } 
    return "danger";
  }

  /**
   * Inclui uma nova questão
   * @param $form -> Array com os dados do POST
   *
   * @return 'success' -> cadastrada com sucesso
   * @return 'warning' -> Caso já exista
   * @return 'danger' -> Algum erro de processamento
   */
  public function incluir( $form, $id )
  {
    if($form['mat_id'] != 'null')
    {
      $data = array('sim_id'=> $id, 'sq_anulada'=> '0', 'mat_id'=> $form['mat_id']);

      $sql = $this->db->insert_string('simulado_questao', $data );
      $this->db->query( $sql );
      if( !$this->db->affected_rows() )
        return 'danger';

      $this->db->update('simulado', array('sim_status'=> 1), array('sim_id'=>$id));
      if( $this->db->affected_rows() )
        return "successn";
    }
    return "danger";
  }

  /**
   * Pega o id da turma da avaliacao
   * @param $id -> ID da turma a consultada
   *
   * @return (1) Objeto da materia
   * @return (2) false
   */
  public function get_turma_id( $id )
  {
    $this->db->select('tur_id');
    $this->db->from('simulado');
    $this->db->where('sim_id', $id);
    $turma = $this->db->get();
    $turma = $turma->result();

    if( !empty($turma) )
    {
      $turma = current( $turma );
      return $turma->tur_id;
    }

    return false;
  }

  /**
   * Lista apenas um simulado
   * @param $id -> ID da turma a consultada
   *
   * @return (1) Objeto da materia
   * @return (2) false
   */
  public function get_simulado( $id )
  {
    $simulado = $this->db->get_where('simulado', array('sim_id'=>$id));
    $simulado = $simulado->result();

    if( !empty($simulado) )
      return current( $simulado );

    return false;
  }

  /**
   * Lista apenas um simulado
   * @param $id -> ID da turma a consultada
   *
   * @return (1) Objeto
   * @return (2) false
   */
  public function get_simulado_bimestre( $bimestre )
  {
              $this->db->select('*');
              $this->db->from('simulado');
              $this->db->join('turma', 'simulado.tur_id = turma.tur_id');
              $this->db->join('fase_escolar', 'turma.fas_id = fase_escolar.fas_id');
              $this->db->where('sim_bimestre', $bimestre);
    $simulado = $this->db->get();
    $simulado = $simulado->result();

    if( !empty($simulado) )
      return current( $simulado );

    return false;
  }

  /**
   * Lista todas os simulados
   *
   * @return Array de objetos
   */
  public function get_simulados( $bimestre )
  {
    $simulados = $this->db->get_where('simulado', array('sim_bimestre'=>$bimestre));
    return $simulados->result();
  }

  /**
   * Lista todas as questoes da tabela intermediaria
   *
   * @return Array de objetos
   */
  public function get_questoes( $id )
  {
    $sql  = "SELECT * FROM simulado_questao sq ";
    $sql .= "JOIN materia m ON sq.mat_id = m.mat_id ";
    $sql .= "WHERE sim_id=?";

    $result = $this->db->query($sql, array($id));
    return $result->result();
  }

  /**
   * Lista todas as questoes da tabela intermediaria
   *
   * @return Array de objetos
   */
  public function get_simulado_questao( $id, $group_by = false )
  {
    $sql  = "SELECT * FROM simulado_questao aq ";
    $sql .= "JOIN materia m ON aq.mat_id = m.mat_id ";
    $sql .= "JOIN simulado s ON aq.sim_id = s.sim_id ";
    $sql .= "JOIN turma t ON s.tur_id = t.tur_id ";
    $sql .= "JOIN fase_escolar f ON t.fas_id = f.fas_id ";
    $sql .= "WHERE aq.mat_id=? AND aq.que_id is null";
    if( $group_by )
      $sql .= " GROUP BY aq.sim_id ";

    $result = $this->db->query($sql, array($id));
    return $result->result();
  }

  /**
   * Excluir
   */
  public function excluir( $id )
  {
    $q = $this->db->get_where('simulado_questao', array('sq_id'=>$id));
    foreach ($q->result() as $key) 
    {
      $sim_id = $key->sim_id;
    }

    $this->db->where('sq_id', $id);
    $this->db->delete('simulado_questao');
    if( $this->db->affected_rows() )
    {
      $this->update_status_simulado($sim_id);
      //direcionando para a parte 2
      header("location:../editar/".$sim_id); 
    }
    return 'danger';
  }

  /**
   * Funcao que atualiza o status do SIMULADO para "pronta para gerar prova"
   */
  public function update_status_questao_simulado($sq_id)
  {
    $rs = $this->db->get_where('simulado_questao', 'sq_id='.$sq_id);
    if( !$this->db->affected_rows() )
      return;
    
    $rs = current( $rs->result() );
    $sim_id = $rs->sim_id;

    $this->update_status_simulado($sim_id);
  }

  private function update_status_simulado($sim_id)
  {
    $rs = $this->db->get_where('simulado_questao', array('sim_id'=>$sim_id, 'que_id'=>null) );
    if( $rs->num_rows() == 0 )
      $this->db->update('simulado', array('sim_status'=> 2), array('sim_id'=>$sim_id));
  }

  /**
   * Muda a opção discursiva da questao
   */
  public function alterarquestao( $id )
  {
  //   $q = $this->db->get_where('avaliacao_questao', array('aq_id'=>$id));
  //   foreach ($q->result() as $key) 
  //   {
  //     $ava_id = $key->ava_id;
  //     if($key->aq_discursiva == 0)
  //     {
  //       $data = array('aq_discursiva'=> 1);
  //     }
  //     else
  //     {
  //       $data = array('aq_discursiva'=> 0);
  //     }
  //   }
    
  //   $result = $this->db->update('avaliacao_questao', $data, array('aq_id'=>$id));
  //   if( $result )
  //   {
  //     //direcionando para a parte 2
  //     header("location:../editar/".$ava_id); 
  //   }
  //   return 'danger';
  }
}
